@@ -442,7 +442,7 @@ impl<'a> LLE_W<'a> {
 pub enum LOE_A {
     #[doc = "0: No List Object Error since last (most recent) flag reset."]
     VALUE1 = 0,
-    #[doc = "1: A List Object Error has been detected during message acceptance filtering. A message object with wrong LIST index entry in the Message Object Control Register has been detected."]
+    #[doc = "1: A List Object Error has been detected during message acceptance filtering. A message object with wrong LIST index entry in the Message Object Status Register has been detected."]
     VALUE2 = 1,
 }
 impl From<LOE_A> for bool {
@@ -498,7 +498,7 @@ impl<'a> LOE_W<'a> {
     pub fn value1(self) -> &'a mut W {
         self.variant(LOE_A::VALUE1)
     }
-    #[doc = "A List Object Error has been detected during message acceptance filtering. A message object with wrong LIST index entry in the Message Object Control Register has been detected."]
+    #[doc = "A List Object Error has been detected during message acceptance filtering. A message object with wrong LIST index entry in the Message Object Status Register has been detected."]
     #[inline(always)]
     pub fn value2(self) -> &'a mut W {
         self.variant(LOE_A::VALUE2)
@@ -520,52 +520,6 @@ impl<'a> LOE_W<'a> {
         self.w
     }
 }
-#[doc = "Suspend Acknowledge\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum SUSACK_A {
-    #[doc = "0: The CAN node is not in Suspend Mode or a suspend request is pending, but the CAN node has not yet reached bus-idle or bus-off."]
-    VALUE1 = 0,
-    #[doc = "1: The CAN node is in Suspend Mode: The CAN node is inactive (bit NCR.INIT internally forced to 1) due to an OCDS suspend request."]
-    VALUE2 = 1,
-}
-impl From<SUSACK_A> for bool {
-    #[inline(always)]
-    fn from(variant: SUSACK_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `SUSACK` reader - Suspend Acknowledge"]
-pub struct SUSACK_R(crate::FieldReader<bool, SUSACK_A>);
-impl SUSACK_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        SUSACK_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> SUSACK_A {
-        match self.bits {
-            false => SUSACK_A::VALUE1,
-            true => SUSACK_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == SUSACK_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == SUSACK_A::VALUE2
-    }
-}
-impl core::ops::Deref for SUSACK_R {
-    type Target = crate::FieldReader<bool, SUSACK_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
 impl R {
     #[doc = "Bits 0:2 - Last Error Code"]
     #[inline(always)]
@@ -607,11 +561,6 @@ impl R {
     pub fn loe(&self) -> LOE_R {
         LOE_R::new(((self.bits >> 9) & 0x01) != 0)
     }
-    #[doc = "Bit 10 - Suspend Acknowledge"]
-    #[inline(always)]
-    pub fn susack(&self) -> SUSACK_R {
-        SUSACK_R::new(((self.bits >> 10) & 0x01) != 0)
-    }
 }
 impl W {
     #[doc = "Bits 0:2 - Last Error Code"]
