@@ -38,9 +38,9 @@ impl From<crate::W<LNEN_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN0_A {
     #[doc = "0: Disables the line"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<LN0_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl LN0_R {
     #[inline(always)]
     pub fn variant(&self) -> LN0_A {
         match self.bits {
-            false => LN0_A::VALUE1,
-            true => LN0_A::VALUE2,
+            false => LN0_A::CONST_0,
+            true => LN0_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LN0_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == LN0_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LN0_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == LN0_A::CONST_1
     }
 }
 impl core::ops::Deref for LN0_R {
@@ -92,13 +92,13 @@ impl<'a> LN0_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LN0_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(LN0_A::CONST_0)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LN0_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(LN0_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> LN0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN1_A {
     #[doc = "0: Disables the line"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<LN1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl LN1_R {
     #[inline(always)]
     pub fn variant(&self) -> LN1_A {
         match self.bits {
-            false => LN1_A::VALUE1,
-            true => LN1_A::VALUE2,
+            false => LN1_A::CONST_0,
+            true => LN1_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LN1_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == LN1_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LN1_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == LN1_A::CONST_1
     }
 }
 impl core::ops::Deref for LN1_R {
@@ -175,13 +175,13 @@ impl<'a> LN1_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LN1_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(LN1_A::CONST_0)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LN1_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(LN1_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> LN1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN2_A {
     #[doc = "0: Disables the line"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<LN2_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl LN2_R {
     #[inline(always)]
     pub fn variant(&self) -> LN2_A {
         match self.bits {
-            false => LN2_A::VALUE1,
-            true => LN2_A::VALUE2,
+            false => LN2_A::CONST_0,
+            true => LN2_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LN2_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == LN2_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LN2_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == LN2_A::CONST_1
     }
 }
 impl core::ops::Deref for LN2_R {
@@ -258,13 +258,13 @@ impl<'a> LN2_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LN2_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(LN2_A::CONST_0)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LN2_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(LN2_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> LN2_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN3_A {
     #[doc = "0: Disables the line"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<LN3_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl LN3_R {
     #[inline(always)]
     pub fn variant(&self) -> LN3_A {
         match self.bits {
-            false => LN3_A::VALUE1,
-            true => LN3_A::VALUE2,
+            false => LN3_A::CONST_0,
+            true => LN3_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LN3_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == LN3_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LN3_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == LN3_A::CONST_1
     }
 }
 impl core::ops::Deref for LN3_R {
@@ -341,13 +341,13 @@ impl<'a> LN3_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LN3_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(LN3_A::CONST_0)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LN3_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(LN3_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> LN3_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN4_A {
     #[doc = "0: Disables the line"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<LN4_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl LN4_R {
     #[inline(always)]
     pub fn variant(&self) -> LN4_A {
         match self.bits {
-            false => LN4_A::VALUE1,
-            true => LN4_A::VALUE2,
+            false => LN4_A::CONST_0,
+            true => LN4_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LN4_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == LN4_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LN4_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == LN4_A::CONST_1
     }
 }
 impl core::ops::Deref for LN4_R {
@@ -424,13 +424,13 @@ impl<'a> LN4_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LN4_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(LN4_A::CONST_0)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LN4_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(LN4_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> LN4_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN5_A {
     #[doc = "0: Disables the line"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<LN5_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl LN5_R {
     #[inline(always)]
     pub fn variant(&self) -> LN5_A {
         match self.bits {
-            false => LN5_A::VALUE1,
-            true => LN5_A::VALUE2,
+            false => LN5_A::CONST_0,
+            true => LN5_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LN5_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == LN5_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LN5_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == LN5_A::CONST_1
     }
 }
 impl core::ops::Deref for LN5_R {
@@ -507,13 +507,13 @@ impl<'a> LN5_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LN5_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(LN5_A::CONST_0)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LN5_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(LN5_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> LN5_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN6_A {
     #[doc = "0: Disables the line"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<LN6_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl LN6_R {
     #[inline(always)]
     pub fn variant(&self) -> LN6_A {
         match self.bits {
-            false => LN6_A::VALUE1,
-            true => LN6_A::VALUE2,
+            false => LN6_A::CONST_0,
+            true => LN6_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LN6_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == LN6_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LN6_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == LN6_A::CONST_1
     }
 }
 impl core::ops::Deref for LN6_R {
@@ -590,13 +590,13 @@ impl<'a> LN6_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LN6_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(LN6_A::CONST_0)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LN6_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(LN6_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +619,9 @@ impl<'a> LN6_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN7_A {
     #[doc = "0: Disables the line"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<LN7_A> for bool {
     #[inline(always)]
@@ -639,19 +639,19 @@ impl LN7_R {
     #[inline(always)]
     pub fn variant(&self) -> LN7_A {
         match self.bits {
-            false => LN7_A::VALUE1,
-            true => LN7_A::VALUE2,
+            false => LN7_A::CONST_0,
+            true => LN7_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LN7_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == LN7_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LN7_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == LN7_A::CONST_1
     }
 }
 impl core::ops::Deref for LN7_R {
@@ -673,13 +673,13 @@ impl<'a> LN7_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LN7_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(LN7_A::CONST_0)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LN7_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(LN7_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
