@@ -17,9 +17,9 @@ impl From<crate::R<PDISC_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS0_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS0_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl PDIS0_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS0_A {
         match self.bits {
-            false => PDIS0_A::VALUE1,
-            true => PDIS0_A::VALUE2,
+            false => PDIS0_A::CONST_0,
+            true => PDIS0_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS0_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS0_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS0_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS0_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS0_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for PDIS0_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS1_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS1_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl PDIS1_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS1_A {
         match self.bits {
-            false => PDIS1_A::VALUE1,
-            true => PDIS1_A::VALUE2,
+            false => PDIS1_A::CONST_0,
+            true => PDIS1_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS1_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS1_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS1_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS1_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS1_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for PDIS1_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS2_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS2_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl PDIS2_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS2_A {
         match self.bits {
-            false => PDIS2_A::VALUE1,
-            true => PDIS2_A::VALUE2,
+            false => PDIS2_A::CONST_0,
+            true => PDIS2_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS2_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS2_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS2_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS2_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS2_R {
@@ -155,9 +155,9 @@ impl core::ops::Deref for PDIS2_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS3_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS3_A> for bool {
     #[inline(always)]
@@ -175,19 +175,19 @@ impl PDIS3_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS3_A {
         match self.bits {
-            false => PDIS3_A::VALUE1,
-            true => PDIS3_A::VALUE2,
+            false => PDIS3_A::CONST_0,
+            true => PDIS3_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS3_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS3_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS3_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS3_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS3_R {
@@ -201,9 +201,9 @@ impl core::ops::Deref for PDIS3_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS4_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS4_A> for bool {
     #[inline(always)]
@@ -221,19 +221,19 @@ impl PDIS4_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS4_A {
         match self.bits {
-            false => PDIS4_A::VALUE1,
-            true => PDIS4_A::VALUE2,
+            false => PDIS4_A::CONST_0,
+            true => PDIS4_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS4_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS4_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS4_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS4_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS4_R {
@@ -247,9 +247,9 @@ impl core::ops::Deref for PDIS4_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS5_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS5_A> for bool {
     #[inline(always)]
@@ -267,19 +267,19 @@ impl PDIS5_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS5_A {
         match self.bits {
-            false => PDIS5_A::VALUE1,
-            true => PDIS5_A::VALUE2,
+            false => PDIS5_A::CONST_0,
+            true => PDIS5_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS5_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS5_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS5_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS5_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS5_R {
@@ -293,9 +293,9 @@ impl core::ops::Deref for PDIS5_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS6_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS6_A> for bool {
     #[inline(always)]
@@ -313,19 +313,19 @@ impl PDIS6_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS6_A {
         match self.bits {
-            false => PDIS6_A::VALUE1,
-            true => PDIS6_A::VALUE2,
+            false => PDIS6_A::CONST_0,
+            true => PDIS6_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS6_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS6_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS6_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS6_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS6_R {
@@ -339,9 +339,9 @@ impl core::ops::Deref for PDIS6_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS7_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS7_A> for bool {
     #[inline(always)]
@@ -359,19 +359,19 @@ impl PDIS7_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS7_A {
         match self.bits {
-            false => PDIS7_A::VALUE1,
-            true => PDIS7_A::VALUE2,
+            false => PDIS7_A::CONST_0,
+            true => PDIS7_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS7_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS7_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS7_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS7_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS7_R {
@@ -385,9 +385,9 @@ impl core::ops::Deref for PDIS7_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS8_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS8_A> for bool {
     #[inline(always)]
@@ -405,19 +405,19 @@ impl PDIS8_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS8_A {
         match self.bits {
-            false => PDIS8_A::VALUE1,
-            true => PDIS8_A::VALUE2,
+            false => PDIS8_A::CONST_0,
+            true => PDIS8_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS8_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS8_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS8_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS8_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS8_R {
@@ -431,9 +431,9 @@ impl core::ops::Deref for PDIS8_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS9_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS9_A> for bool {
     #[inline(always)]
@@ -451,19 +451,19 @@ impl PDIS9_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS9_A {
         match self.bits {
-            false => PDIS9_A::VALUE1,
-            true => PDIS9_A::VALUE2,
+            false => PDIS9_A::CONST_0,
+            true => PDIS9_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS9_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS9_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS9_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS9_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS9_R {
@@ -477,9 +477,9 @@ impl core::ops::Deref for PDIS9_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS10_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS10_A> for bool {
     #[inline(always)]
@@ -497,19 +497,19 @@ impl PDIS10_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS10_A {
         match self.bits {
-            false => PDIS10_A::VALUE1,
-            true => PDIS10_A::VALUE2,
+            false => PDIS10_A::CONST_0,
+            true => PDIS10_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS10_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS10_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS10_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS10_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS10_R {
@@ -523,9 +523,9 @@ impl core::ops::Deref for PDIS10_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS11_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS11_A> for bool {
     #[inline(always)]
@@ -543,19 +543,19 @@ impl PDIS11_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS11_A {
         match self.bits {
-            false => PDIS11_A::VALUE1,
-            true => PDIS11_A::VALUE2,
+            false => PDIS11_A::CONST_0,
+            true => PDIS11_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS11_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS11_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS11_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS11_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS11_R {
@@ -569,9 +569,9 @@ impl core::ops::Deref for PDIS11_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS12_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS12_A> for bool {
     #[inline(always)]
@@ -589,19 +589,19 @@ impl PDIS12_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS12_A {
         match self.bits {
-            false => PDIS12_A::VALUE1,
-            true => PDIS12_A::VALUE2,
+            false => PDIS12_A::CONST_0,
+            true => PDIS12_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS12_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS12_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS12_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS12_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS12_R {
@@ -615,9 +615,9 @@ impl core::ops::Deref for PDIS12_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS13_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS13_A> for bool {
     #[inline(always)]
@@ -635,19 +635,19 @@ impl PDIS13_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS13_A {
         match self.bits {
-            false => PDIS13_A::VALUE1,
-            true => PDIS13_A::VALUE2,
+            false => PDIS13_A::CONST_0,
+            true => PDIS13_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS13_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS13_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS13_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS13_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS13_R {
@@ -661,9 +661,9 @@ impl core::ops::Deref for PDIS13_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS14_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS14_A> for bool {
     #[inline(always)]
@@ -681,19 +681,19 @@ impl PDIS14_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS14_A {
         match self.bits {
-            false => PDIS14_A::VALUE1,
-            true => PDIS14_A::VALUE2,
+            false => PDIS14_A::CONST_0,
+            true => PDIS14_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS14_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS14_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS14_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS14_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS14_R {
@@ -707,9 +707,9 @@ impl core::ops::Deref for PDIS14_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS15_A {
     #[doc = "0: Pad Pn.x is enabled."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Pad Pn.x is disabled."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS15_A> for bool {
     #[inline(always)]
@@ -727,19 +727,19 @@ impl PDIS15_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS15_A {
         match self.bits {
-            false => PDIS15_A::VALUE1,
-            true => PDIS15_A::VALUE2,
+            false => PDIS15_A::CONST_0,
+            true => PDIS15_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS15_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS15_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS15_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS15_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS15_R {
