@@ -38,9 +38,9 @@ impl From<crate::W<PDISC_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS0_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS0_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl PDIS0_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS0_A {
         match self.bits {
-            false => PDIS0_A::VALUE1,
-            true => PDIS0_A::VALUE2,
+            false => PDIS0_A::CONST_0,
+            true => PDIS0_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS0_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS0_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS0_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS0_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS0_R {
@@ -92,13 +92,13 @@ impl<'a> PDIS0_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS0_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS0_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS0_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS0_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> PDIS0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS1_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl PDIS1_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS1_A {
         match self.bits {
-            false => PDIS1_A::VALUE1,
-            true => PDIS1_A::VALUE2,
+            false => PDIS1_A::CONST_0,
+            true => PDIS1_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS1_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS1_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS1_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS1_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS1_R {
@@ -175,13 +175,13 @@ impl<'a> PDIS1_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS1_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS1_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS1_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS1_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> PDIS1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS2_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS2_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl PDIS2_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS2_A {
         match self.bits {
-            false => PDIS2_A::VALUE1,
-            true => PDIS2_A::VALUE2,
+            false => PDIS2_A::CONST_0,
+            true => PDIS2_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS2_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS2_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS2_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS2_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS2_R {
@@ -258,13 +258,13 @@ impl<'a> PDIS2_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS2_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS2_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS2_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS2_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> PDIS2_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS3_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS3_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl PDIS3_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS3_A {
         match self.bits {
-            false => PDIS3_A::VALUE1,
-            true => PDIS3_A::VALUE2,
+            false => PDIS3_A::CONST_0,
+            true => PDIS3_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS3_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS3_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS3_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS3_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS3_R {
@@ -341,13 +341,13 @@ impl<'a> PDIS3_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS3_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS3_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS3_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS3_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> PDIS3_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS4_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS4_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl PDIS4_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS4_A {
         match self.bits {
-            false => PDIS4_A::VALUE1,
-            true => PDIS4_A::VALUE2,
+            false => PDIS4_A::CONST_0,
+            true => PDIS4_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS4_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS4_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS4_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS4_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS4_R {
@@ -424,13 +424,13 @@ impl<'a> PDIS4_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS4_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS4_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS4_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS4_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> PDIS4_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS5_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS5_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl PDIS5_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS5_A {
         match self.bits {
-            false => PDIS5_A::VALUE1,
-            true => PDIS5_A::VALUE2,
+            false => PDIS5_A::CONST_0,
+            true => PDIS5_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS5_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS5_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS5_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS5_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS5_R {
@@ -507,13 +507,13 @@ impl<'a> PDIS5_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS5_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS5_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS5_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS5_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> PDIS5_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS6_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS6_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl PDIS6_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS6_A {
         match self.bits {
-            false => PDIS6_A::VALUE1,
-            true => PDIS6_A::VALUE2,
+            false => PDIS6_A::CONST_0,
+            true => PDIS6_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS6_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS6_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS6_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS6_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS6_R {
@@ -590,13 +590,13 @@ impl<'a> PDIS6_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS6_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS6_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS6_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS6_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +619,9 @@ impl<'a> PDIS6_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS7_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS7_A> for bool {
     #[inline(always)]
@@ -639,19 +639,19 @@ impl PDIS7_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS7_A {
         match self.bits {
-            false => PDIS7_A::VALUE1,
-            true => PDIS7_A::VALUE2,
+            false => PDIS7_A::CONST_0,
+            true => PDIS7_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS7_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS7_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS7_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS7_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS7_R {
@@ -673,13 +673,13 @@ impl<'a> PDIS7_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS7_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS7_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS7_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS7_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -702,9 +702,9 @@ impl<'a> PDIS7_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS8_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS8_A> for bool {
     #[inline(always)]
@@ -722,19 +722,19 @@ impl PDIS8_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS8_A {
         match self.bits {
-            false => PDIS8_A::VALUE1,
-            true => PDIS8_A::VALUE2,
+            false => PDIS8_A::CONST_0,
+            true => PDIS8_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS8_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS8_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS8_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS8_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS8_R {
@@ -756,13 +756,13 @@ impl<'a> PDIS8_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS8_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS8_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS8_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS8_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +785,9 @@ impl<'a> PDIS8_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS9_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS9_A> for bool {
     #[inline(always)]
@@ -805,19 +805,19 @@ impl PDIS9_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS9_A {
         match self.bits {
-            false => PDIS9_A::VALUE1,
-            true => PDIS9_A::VALUE2,
+            false => PDIS9_A::CONST_0,
+            true => PDIS9_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS9_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS9_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS9_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS9_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS9_R {
@@ -839,13 +839,13 @@ impl<'a> PDIS9_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS9_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS9_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS9_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS9_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +868,9 @@ impl<'a> PDIS9_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS10_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS10_A> for bool {
     #[inline(always)]
@@ -888,19 +888,19 @@ impl PDIS10_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS10_A {
         match self.bits {
-            false => PDIS10_A::VALUE1,
-            true => PDIS10_A::VALUE2,
+            false => PDIS10_A::CONST_0,
+            true => PDIS10_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS10_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS10_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS10_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS10_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS10_R {
@@ -922,13 +922,13 @@ impl<'a> PDIS10_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS10_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS10_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS10_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS10_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -951,9 +951,9 @@ impl<'a> PDIS10_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS11_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS11_A> for bool {
     #[inline(always)]
@@ -971,19 +971,19 @@ impl PDIS11_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS11_A {
         match self.bits {
-            false => PDIS11_A::VALUE1,
-            true => PDIS11_A::VALUE2,
+            false => PDIS11_A::CONST_0,
+            true => PDIS11_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS11_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS11_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS11_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS11_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS11_R {
@@ -1005,13 +1005,13 @@ impl<'a> PDIS11_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS11_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS11_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS11_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS11_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1034,9 +1034,9 @@ impl<'a> PDIS11_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS12_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS12_A> for bool {
     #[inline(always)]
@@ -1054,19 +1054,19 @@ impl PDIS12_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS12_A {
         match self.bits {
-            false => PDIS12_A::VALUE1,
-            true => PDIS12_A::VALUE2,
+            false => PDIS12_A::CONST_0,
+            true => PDIS12_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS12_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS12_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS12_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS12_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS12_R {
@@ -1088,13 +1088,13 @@ impl<'a> PDIS12_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS12_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS12_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS12_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS12_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1117,9 +1117,9 @@ impl<'a> PDIS12_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS13_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS13_A> for bool {
     #[inline(always)]
@@ -1137,19 +1137,19 @@ impl PDIS13_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS13_A {
         match self.bits {
-            false => PDIS13_A::VALUE1,
-            true => PDIS13_A::VALUE2,
+            false => PDIS13_A::CONST_0,
+            true => PDIS13_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS13_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS13_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS13_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS13_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS13_R {
@@ -1171,13 +1171,13 @@ impl<'a> PDIS13_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS13_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS13_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS13_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS13_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1200,9 +1200,9 @@ impl<'a> PDIS13_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS14_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS14_A> for bool {
     #[inline(always)]
@@ -1220,19 +1220,19 @@ impl PDIS14_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS14_A {
         match self.bits {
-            false => PDIS14_A::VALUE1,
-            true => PDIS14_A::VALUE2,
+            false => PDIS14_A::CONST_0,
+            true => PDIS14_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS14_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS14_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS14_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS14_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS14_R {
@@ -1254,13 +1254,13 @@ impl<'a> PDIS14_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS14_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS14_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS14_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS14_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1283,9 +1283,9 @@ impl<'a> PDIS14_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PDIS15_A {
     #[doc = "0: Digital Pad input is enabled. Analog and digital input path active."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Digital Pad input is disabled. Analog input path active. (default)"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PDIS15_A> for bool {
     #[inline(always)]
@@ -1303,19 +1303,19 @@ impl PDIS15_R {
     #[inline(always)]
     pub fn variant(&self) -> PDIS15_A {
         match self.bits {
-            false => PDIS15_A::VALUE1,
-            true => PDIS15_A::VALUE2,
+            false => PDIS15_A::CONST_0,
+            true => PDIS15_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PDIS15_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PDIS15_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PDIS15_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PDIS15_A::CONST_1
     }
 }
 impl core::ops::Deref for PDIS15_R {
@@ -1337,13 +1337,13 @@ impl<'a> PDIS15_W<'a> {
     }
     #[doc = "Digital Pad input is enabled. Analog and digital input path active."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PDIS15_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PDIS15_A::CONST_0)
     }
     #[doc = "Digital Pad input is disabled. Analog input path active. (default)"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PDIS15_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PDIS15_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
