@@ -38,9 +38,9 @@ impl From<crate::W<DSLEEPCR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SYSSEL_A {
     #[doc = "0: fOFI clock"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: fPLL clock"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<SYSSEL_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl SYSSEL_R {
     #[inline(always)]
     pub fn variant(&self) -> SYSSEL_A {
         match self.bits {
-            false => SYSSEL_A::VALUE1,
-            true => SYSSEL_A::VALUE2,
+            false => SYSSEL_A::CONST_0,
+            true => SYSSEL_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == SYSSEL_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == SYSSEL_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == SYSSEL_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == SYSSEL_A::CONST_1
     }
 }
 impl core::ops::Deref for SYSSEL_R {
@@ -92,13 +92,13 @@ impl<'a> SYSSEL_W<'a> {
     }
     #[doc = "fOFI clock"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(SYSSEL_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(SYSSEL_A::CONST_0)
     }
     #[doc = "fPLL clock"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(SYSSEL_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(SYSSEL_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> SYSSEL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum FPDN_A {
     #[doc = "1: Flash power down module"]
-    VALUE1 = 1,
+    CONST_1 = 1,
     #[doc = "0: No effect"]
-    VALUE2 = 0,
+    CONST_0 = 0,
 }
 impl From<FPDN_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl FPDN_R {
     #[inline(always)]
     pub fn variant(&self) -> FPDN_A {
         match self.bits {
-            true => FPDN_A::VALUE1,
-            false => FPDN_A::VALUE2,
+            true => FPDN_A::CONST_1,
+            false => FPDN_A::CONST_0,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == FPDN_A::VALUE1
+    pub fn is_const_1(&self) -> bool {
+        **self == FPDN_A::CONST_1
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == FPDN_A::VALUE2
+    pub fn is_const_0(&self) -> bool {
+        **self == FPDN_A::CONST_0
     }
 }
 impl core::ops::Deref for FPDN_R {
@@ -175,13 +175,13 @@ impl<'a> FPDN_W<'a> {
     }
     #[doc = "Flash power down module"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(FPDN_A::VALUE1)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(FPDN_A::CONST_1)
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(FPDN_A::VALUE2)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(FPDN_A::CONST_0)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> FPDN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PLLPDN_A {
     #[doc = "1: Switch off main PLL"]
-    VALUE1 = 1,
+    CONST_1 = 1,
     #[doc = "0: No effect"]
-    VALUE2 = 0,
+    CONST_0 = 0,
 }
 impl From<PLLPDN_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl PLLPDN_R {
     #[inline(always)]
     pub fn variant(&self) -> PLLPDN_A {
         match self.bits {
-            true => PLLPDN_A::VALUE1,
-            false => PLLPDN_A::VALUE2,
+            true => PLLPDN_A::CONST_1,
+            false => PLLPDN_A::CONST_0,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PLLPDN_A::VALUE1
+    pub fn is_const_1(&self) -> bool {
+        **self == PLLPDN_A::CONST_1
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PLLPDN_A::VALUE2
+    pub fn is_const_0(&self) -> bool {
+        **self == PLLPDN_A::CONST_0
     }
 }
 impl core::ops::Deref for PLLPDN_R {
@@ -258,13 +258,13 @@ impl<'a> PLLPDN_W<'a> {
     }
     #[doc = "Switch off main PLL"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PLLPDN_A::VALUE1)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PLLPDN_A::CONST_1)
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PLLPDN_A::VALUE2)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PLLPDN_A::CONST_0)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> PLLPDN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum VCOPDN_A {
     #[doc = "1: Switch off VCO of main PLL"]
-    VALUE1 = 1,
+    CONST_1 = 1,
     #[doc = "0: No effect"]
-    VALUE2 = 0,
+    CONST_0 = 0,
 }
 impl From<VCOPDN_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl VCOPDN_R {
     #[inline(always)]
     pub fn variant(&self) -> VCOPDN_A {
         match self.bits {
-            true => VCOPDN_A::VALUE1,
-            false => VCOPDN_A::VALUE2,
+            true => VCOPDN_A::CONST_1,
+            false => VCOPDN_A::CONST_0,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == VCOPDN_A::VALUE1
+    pub fn is_const_1(&self) -> bool {
+        **self == VCOPDN_A::CONST_1
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == VCOPDN_A::VALUE2
+    pub fn is_const_0(&self) -> bool {
+        **self == VCOPDN_A::CONST_0
     }
 }
 impl core::ops::Deref for VCOPDN_R {
@@ -341,13 +341,13 @@ impl<'a> VCOPDN_W<'a> {
     }
     #[doc = "Switch off VCO of main PLL"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(VCOPDN_A::VALUE1)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(VCOPDN_A::CONST_1)
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(VCOPDN_A::VALUE2)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(VCOPDN_A::CONST_0)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -366,13 +366,13 @@ impl<'a> VCOPDN_W<'a> {
         self.w
     }
 }
-#[doc = "USB Clock Control\n\nValue on reset: 0"]
+#[doc = "USB Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBCR_A {
-    #[doc = "0: Disable"]
-    VALUE1 = 0,
-    #[doc = "1: Enable"]
-    VALUE2 = 1,
+    #[doc = "0: Disabled"]
+    CONST_0 = 0,
+    #[doc = "1: Enabled"]
+    CONST_1 = 1,
 }
 impl From<USBCR_A> for bool {
     #[inline(always)]
@@ -380,7 +380,7 @@ impl From<USBCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `USBCR` reader - USB Clock Control"]
+#[doc = "Field `USBCR` reader - USB Clock Control in Deep Sleep Mode"]
 pub struct USBCR_R(crate::FieldReader<bool, USBCR_A>);
 impl USBCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -390,19 +390,19 @@ impl USBCR_R {
     #[inline(always)]
     pub fn variant(&self) -> USBCR_A {
         match self.bits {
-            false => USBCR_A::VALUE1,
-            true => USBCR_A::VALUE2,
+            false => USBCR_A::CONST_0,
+            true => USBCR_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == USBCR_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == USBCR_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == USBCR_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == USBCR_A::CONST_1
     }
 }
 impl core::ops::Deref for USBCR_R {
@@ -412,7 +412,7 @@ impl core::ops::Deref for USBCR_R {
         &self.0
     }
 }
-#[doc = "Field `USBCR` writer - USB Clock Control"]
+#[doc = "Field `USBCR` writer - USB Clock Control in Deep Sleep Mode"]
 pub struct USBCR_W<'a> {
     w: &'a mut W,
 }
@@ -422,15 +422,15 @@ impl<'a> USBCR_W<'a> {
     pub fn variant(self, variant: USBCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disable"]
+    #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(USBCR_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(USBCR_A::CONST_0)
     }
-    #[doc = "Enable"]
+    #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(USBCR_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(USBCR_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -449,13 +449,179 @@ impl<'a> USBCR_W<'a> {
         self.w
     }
 }
-#[doc = "CCU Clock Control\n\nValue on reset: 0"]
+#[doc = "MMC Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MMCCR_A {
+    #[doc = "0: Disabled"]
+    CONST_0 = 0,
+    #[doc = "1: Enabled"]
+    CONST_1 = 1,
+}
+impl From<MMCCR_A> for bool {
+    #[inline(always)]
+    fn from(variant: MMCCR_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `MMCCR` reader - MMC Clock Control in Deep Sleep Mode"]
+pub struct MMCCR_R(crate::FieldReader<bool, MMCCR_A>);
+impl MMCCR_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MMCCR_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MMCCR_A {
+        match self.bits {
+            false => MMCCR_A::CONST_0,
+            true => MMCCR_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == MMCCR_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == MMCCR_A::CONST_1
+    }
+}
+impl core::ops::Deref for MMCCR_R {
+    type Target = crate::FieldReader<bool, MMCCR_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MMCCR` writer - MMC Clock Control in Deep Sleep Mode"]
+pub struct MMCCR_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> MMCCR_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: MMCCR_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disabled"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MMCCR_A::CONST_0)
+    }
+    #[doc = "Enabled"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MMCCR_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w
+    }
+}
+#[doc = "Ethernet Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum ETH0CR_A {
+    #[doc = "0: Disabled"]
+    CONST_0 = 0,
+    #[doc = "1: Enabled"]
+    CONST_1 = 1,
+}
+impl From<ETH0CR_A> for bool {
+    #[inline(always)]
+    fn from(variant: ETH0CR_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `ETH0CR` reader - Ethernet Clock Control in Deep Sleep Mode"]
+pub struct ETH0CR_R(crate::FieldReader<bool, ETH0CR_A>);
+impl ETH0CR_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        ETH0CR_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> ETH0CR_A {
+        match self.bits {
+            false => ETH0CR_A::CONST_0,
+            true => ETH0CR_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == ETH0CR_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == ETH0CR_A::CONST_1
+    }
+}
+impl core::ops::Deref for ETH0CR_R {
+    type Target = crate::FieldReader<bool, ETH0CR_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ETH0CR` writer - Ethernet Clock Control in Deep Sleep Mode"]
+pub struct ETH0CR_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> ETH0CR_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: ETH0CR_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disabled"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(ETH0CR_A::CONST_0)
+    }
+    #[doc = "Enabled"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(ETH0CR_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w
+    }
+}
+#[doc = "CCU Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCUCR_A {
-    #[doc = "0: Disable"]
-    VALUE1 = 0,
-    #[doc = "1: Enable"]
-    VALUE2 = 1,
+    #[doc = "0: Disabled"]
+    CONST_0 = 0,
+    #[doc = "1: Enabled"]
+    CONST_1 = 1,
 }
 impl From<CCUCR_A> for bool {
     #[inline(always)]
@@ -463,7 +629,7 @@ impl From<CCUCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `CCUCR` reader - CCU Clock Control"]
+#[doc = "Field `CCUCR` reader - CCU Clock Control in Deep Sleep Mode"]
 pub struct CCUCR_R(crate::FieldReader<bool, CCUCR_A>);
 impl CCUCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -473,19 +639,19 @@ impl CCUCR_R {
     #[inline(always)]
     pub fn variant(&self) -> CCUCR_A {
         match self.bits {
-            false => CCUCR_A::VALUE1,
-            true => CCUCR_A::VALUE2,
+            false => CCUCR_A::CONST_0,
+            true => CCUCR_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == CCUCR_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == CCUCR_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == CCUCR_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == CCUCR_A::CONST_1
     }
 }
 impl core::ops::Deref for CCUCR_R {
@@ -495,7 +661,7 @@ impl core::ops::Deref for CCUCR_R {
         &self.0
     }
 }
-#[doc = "Field `CCUCR` writer - CCU Clock Control"]
+#[doc = "Field `CCUCR` writer - CCU Clock Control in Deep Sleep Mode"]
 pub struct CCUCR_W<'a> {
     w: &'a mut W,
 }
@@ -505,15 +671,15 @@ impl<'a> CCUCR_W<'a> {
     pub fn variant(self, variant: CCUCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disable"]
+    #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(CCUCR_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(CCUCR_A::CONST_0)
     }
-    #[doc = "Enable"]
+    #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(CCUCR_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(CCUCR_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -532,13 +698,13 @@ impl<'a> CCUCR_W<'a> {
         self.w
     }
 }
-#[doc = "WDT Clock Control\n\nValue on reset: 0"]
+#[doc = "WDT Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDTCR_A {
-    #[doc = "0: Disable"]
-    VALUE1 = 0,
-    #[doc = "1: Enable"]
-    VALUE2 = 1,
+    #[doc = "0: Disabled"]
+    CONST_0 = 0,
+    #[doc = "1: Enabled"]
+    CONST_1 = 1,
 }
 impl From<WDTCR_A> for bool {
     #[inline(always)]
@@ -546,7 +712,7 @@ impl From<WDTCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `WDTCR` reader - WDT Clock Control"]
+#[doc = "Field `WDTCR` reader - WDT Clock Control in Deep Sleep Mode"]
 pub struct WDTCR_R(crate::FieldReader<bool, WDTCR_A>);
 impl WDTCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -556,19 +722,19 @@ impl WDTCR_R {
     #[inline(always)]
     pub fn variant(&self) -> WDTCR_A {
         match self.bits {
-            false => WDTCR_A::VALUE1,
-            true => WDTCR_A::VALUE2,
+            false => WDTCR_A::CONST_0,
+            true => WDTCR_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == WDTCR_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == WDTCR_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == WDTCR_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == WDTCR_A::CONST_1
     }
 }
 impl core::ops::Deref for WDTCR_R {
@@ -578,7 +744,7 @@ impl core::ops::Deref for WDTCR_R {
         &self.0
     }
 }
-#[doc = "Field `WDTCR` writer - WDT Clock Control"]
+#[doc = "Field `WDTCR` writer - WDT Clock Control in Deep Sleep Mode"]
 pub struct WDTCR_W<'a> {
     w: &'a mut W,
 }
@@ -588,15 +754,15 @@ impl<'a> WDTCR_W<'a> {
     pub fn variant(self, variant: WDTCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disable"]
+    #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(WDTCR_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(WDTCR_A::CONST_0)
     }
-    #[doc = "Enable"]
+    #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(WDTCR_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(WDTCR_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -636,17 +802,27 @@ impl R {
     pub fn vcopdn(&self) -> VCOPDN_R {
         VCOPDN_R::new(((self.bits >> 13) & 0x01) != 0)
     }
-    #[doc = "Bit 16 - USB Clock Control"]
+    #[doc = "Bit 16 - USB Clock Control in Deep Sleep Mode"]
     #[inline(always)]
     pub fn usbcr(&self) -> USBCR_R {
         USBCR_R::new(((self.bits >> 16) & 0x01) != 0)
     }
-    #[doc = "Bit 20 - CCU Clock Control"]
+    #[doc = "Bit 17 - MMC Clock Control in Deep Sleep Mode"]
+    #[inline(always)]
+    pub fn mmccr(&self) -> MMCCR_R {
+        MMCCR_R::new(((self.bits >> 17) & 0x01) != 0)
+    }
+    #[doc = "Bit 18 - Ethernet Clock Control in Deep Sleep Mode"]
+    #[inline(always)]
+    pub fn eth0cr(&self) -> ETH0CR_R {
+        ETH0CR_R::new(((self.bits >> 18) & 0x01) != 0)
+    }
+    #[doc = "Bit 20 - CCU Clock Control in Deep Sleep Mode"]
     #[inline(always)]
     pub fn ccucr(&self) -> CCUCR_R {
         CCUCR_R::new(((self.bits >> 20) & 0x01) != 0)
     }
-    #[doc = "Bit 21 - WDT Clock Control"]
+    #[doc = "Bit 21 - WDT Clock Control in Deep Sleep Mode"]
     #[inline(always)]
     pub fn wdtcr(&self) -> WDTCR_R {
         WDTCR_R::new(((self.bits >> 21) & 0x01) != 0)
@@ -673,17 +849,27 @@ impl W {
     pub fn vcopdn(&mut self) -> VCOPDN_W {
         VCOPDN_W { w: self }
     }
-    #[doc = "Bit 16 - USB Clock Control"]
+    #[doc = "Bit 16 - USB Clock Control in Deep Sleep Mode"]
     #[inline(always)]
     pub fn usbcr(&mut self) -> USBCR_W {
         USBCR_W { w: self }
     }
-    #[doc = "Bit 20 - CCU Clock Control"]
+    #[doc = "Bit 17 - MMC Clock Control in Deep Sleep Mode"]
+    #[inline(always)]
+    pub fn mmccr(&mut self) -> MMCCR_W {
+        MMCCR_W { w: self }
+    }
+    #[doc = "Bit 18 - Ethernet Clock Control in Deep Sleep Mode"]
+    #[inline(always)]
+    pub fn eth0cr(&mut self) -> ETH0CR_W {
+        ETH0CR_W { w: self }
+    }
+    #[doc = "Bit 20 - CCU Clock Control in Deep Sleep Mode"]
     #[inline(always)]
     pub fn ccucr(&mut self) -> CCUCR_W {
         CCUCR_W { w: self }
     }
-    #[doc = "Bit 21 - WDT Clock Control"]
+    #[doc = "Bit 21 - WDT Clock Control in Deep Sleep Mode"]
     #[inline(always)]
     pub fn wdtcr(&mut self) -> WDTCR_W {
         WDTCR_W { w: self }
