@@ -64,9 +64,9 @@ impl<'a> SYSDIV_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SYSSEL_A {
     #[doc = "0: fOFI clock"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: fPLL clock"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<SYSSEL_A> for bool {
     #[inline(always)]
@@ -84,19 +84,19 @@ impl SYSSEL_R {
     #[inline(always)]
     pub fn variant(&self) -> SYSSEL_A {
         match self.bits {
-            false => SYSSEL_A::VALUE1,
-            true => SYSSEL_A::VALUE2,
+            false => SYSSEL_A::CONST_0,
+            true => SYSSEL_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == SYSSEL_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == SYSSEL_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == SYSSEL_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == SYSSEL_A::CONST_1
     }
 }
 impl core::ops::Deref for SYSSEL_R {
@@ -118,13 +118,13 @@ impl<'a> SYSSEL_W<'a> {
     }
     #[doc = "fOFI clock"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(SYSSEL_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(SYSSEL_A::CONST_0)
     }
     #[doc = "fPLL clock"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(SYSSEL_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(SYSSEL_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -147,9 +147,9 @@ impl<'a> SYSSEL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CPUDIV_A {
     #[doc = "0: fCPU = fSYS"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: fCPU = fSYS / 2"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<CPUDIV_A> for bool {
     #[inline(always)]
@@ -167,19 +167,19 @@ impl CPUDIV_R {
     #[inline(always)]
     pub fn variant(&self) -> CPUDIV_A {
         match self.bits {
-            false => CPUDIV_A::VALUE1,
-            true => CPUDIV_A::VALUE2,
+            false => CPUDIV_A::CONST_0,
+            true => CPUDIV_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == CPUDIV_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == CPUDIV_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == CPUDIV_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == CPUDIV_A::CONST_1
     }
 }
 impl core::ops::Deref for CPUDIV_R {
@@ -201,13 +201,13 @@ impl<'a> CPUDIV_W<'a> {
     }
     #[doc = "fCPU = fSYS"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(CPUDIV_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(CPUDIV_A::CONST_0)
     }
     #[doc = "fCPU = fSYS / 2"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(CPUDIV_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(CPUDIV_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -230,9 +230,9 @@ impl<'a> CPUDIV_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PBDIV_A {
     #[doc = "0: fPERIPH = fCPU"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: fPERIPH = fCPU / 2"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PBDIV_A> for bool {
     #[inline(always)]
@@ -250,19 +250,19 @@ impl PBDIV_R {
     #[inline(always)]
     pub fn variant(&self) -> PBDIV_A {
         match self.bits {
-            false => PBDIV_A::VALUE1,
-            true => PBDIV_A::VALUE2,
+            false => PBDIV_A::CONST_0,
+            true => PBDIV_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PBDIV_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PBDIV_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PBDIV_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PBDIV_A::CONST_1
     }
 }
 impl core::ops::Deref for PBDIV_R {
@@ -284,13 +284,13 @@ impl<'a> PBDIV_W<'a> {
     }
     #[doc = "fPERIPH = fCPU"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PBDIV_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PBDIV_A::CONST_0)
     }
     #[doc = "fPERIPH = fCPU / 2"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PBDIV_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PBDIV_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -313,9 +313,9 @@ impl<'a> PBDIV_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCUDIV_A {
     #[doc = "0: fCCU = fSYS"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: fCCU = fSYS / 2"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<CCUDIV_A> for bool {
     #[inline(always)]
@@ -333,19 +333,19 @@ impl CCUDIV_R {
     #[inline(always)]
     pub fn variant(&self) -> CCUDIV_A {
         match self.bits {
-            false => CCUDIV_A::VALUE1,
-            true => CCUDIV_A::VALUE2,
+            false => CCUDIV_A::CONST_0,
+            true => CCUDIV_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == CCUDIV_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == CCUDIV_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == CCUDIV_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == CCUDIV_A::CONST_1
     }
 }
 impl core::ops::Deref for CCUDIV_R {
@@ -367,13 +367,13 @@ impl<'a> CCUDIV_W<'a> {
     }
     #[doc = "fCCU = fSYS"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(CCUDIV_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(CCUDIV_A::CONST_0)
     }
     #[doc = "fCCU = fSYS / 2"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(CCUDIV_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(CCUDIV_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -423,11 +423,11 @@ impl<'a> WDTDIV_W<'a> {
 #[repr(u8)]
 pub enum WDTSEL_A {
     #[doc = "0: fOFI clock"]
-    VALUE1 = 0,
+    CONST_00 = 0,
     #[doc = "1: fSTDBY clock"]
-    VALUE2 = 1,
+    CONST_01 = 1,
     #[doc = "2: fPLL clock"]
-    VALUE3 = 2,
+    CONST_10 = 2,
 }
 impl From<WDTSEL_A> for u8 {
     #[inline(always)]
@@ -445,26 +445,26 @@ impl WDTSEL_R {
     #[inline(always)]
     pub fn variant(&self) -> Option<WDTSEL_A> {
         match self.bits {
-            0 => Some(WDTSEL_A::VALUE1),
-            1 => Some(WDTSEL_A::VALUE2),
-            2 => Some(WDTSEL_A::VALUE3),
+            0 => Some(WDTSEL_A::CONST_00),
+            1 => Some(WDTSEL_A::CONST_01),
+            2 => Some(WDTSEL_A::CONST_10),
             _ => None,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_00`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == WDTSEL_A::VALUE1
+    pub fn is_const_00(&self) -> bool {
+        **self == WDTSEL_A::CONST_00
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_01`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == WDTSEL_A::VALUE2
+    pub fn is_const_01(&self) -> bool {
+        **self == WDTSEL_A::CONST_01
     }
-    #[doc = "Checks if the value of the field is `VALUE3`"]
+    #[doc = "Checks if the value of the field is `CONST_10`"]
     #[inline(always)]
-    pub fn is_value3(&self) -> bool {
-        **self == WDTSEL_A::VALUE3
+    pub fn is_const_10(&self) -> bool {
+        **self == WDTSEL_A::CONST_10
     }
 }
 impl core::ops::Deref for WDTSEL_R {
@@ -486,18 +486,18 @@ impl<'a> WDTSEL_W<'a> {
     }
     #[doc = "fOFI clock"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(WDTSEL_A::VALUE1)
+    pub fn const_00(self) -> &'a mut W {
+        self.variant(WDTSEL_A::CONST_00)
     }
     #[doc = "fSTDBY clock"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(WDTSEL_A::VALUE2)
+    pub fn const_01(self) -> &'a mut W {
+        self.variant(WDTSEL_A::CONST_01)
     }
     #[doc = "fPLL clock"]
     #[inline(always)]
-    pub fn value3(self) -> &'a mut W {
-        self.variant(WDTSEL_A::VALUE3)
+    pub fn const_10(self) -> &'a mut W {
+        self.variant(WDTSEL_A::CONST_10)
     }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
