@@ -17,9 +17,9 @@ impl From<crate::R<MIRRSTS_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCLR_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<HDCLR_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl HDCLR_R {
     #[inline(always)]
     pub fn variant(&self) -> HDCLR_A {
         match self.bits {
-            false => HDCLR_A::VALUE1,
-            true => HDCLR_A::VALUE2,
+            false => HDCLR_A::CONST_0,
+            true => HDCLR_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == HDCLR_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == HDCLR_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == HDCLR_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == HDCLR_A::CONST_1
     }
 }
 impl core::ops::Deref for HDCLR_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for HDCLR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDSET_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<HDSET_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl HDSET_R {
     #[inline(always)]
     pub fn variant(&self) -> HDSET_A {
         match self.bits {
-            false => HDSET_A::VALUE1,
-            true => HDSET_A::VALUE2,
+            false => HDSET_A::CONST_0,
+            true => HDSET_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == HDSET_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == HDSET_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == HDSET_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == HDSET_A::CONST_1
     }
 }
 impl core::ops::Deref for HDSET_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for HDSET_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCR_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<HDCR_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl HDCR_R {
     #[inline(always)]
     pub fn variant(&self) -> HDCR_A {
         match self.bits {
-            false => HDCR_A::VALUE1,
-            true => HDCR_A::VALUE2,
+            false => HDCR_A::CONST_0,
+            true => HDCR_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == HDCR_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == HDCR_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == HDCR_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == HDCR_A::CONST_1
     }
 }
 impl core::ops::Deref for HDCR_R {
@@ -155,9 +155,9 @@ impl core::ops::Deref for HDCR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCSICTRL_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<OSCSICTRL_A> for bool {
     #[inline(always)]
@@ -175,19 +175,19 @@ impl OSCSICTRL_R {
     #[inline(always)]
     pub fn variant(&self) -> OSCSICTRL_A {
         match self.bits {
-            false => OSCSICTRL_A::VALUE1,
-            true => OSCSICTRL_A::VALUE2,
+            false => OSCSICTRL_A::CONST_0,
+            true => OSCSICTRL_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == OSCSICTRL_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == OSCSICTRL_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == OSCSICTRL_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == OSCSICTRL_A::CONST_1
     }
 }
 impl core::ops::Deref for OSCSICTRL_R {
@@ -201,9 +201,9 @@ impl core::ops::Deref for OSCSICTRL_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCULCTRL_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<OSCULCTRL_A> for bool {
     #[inline(always)]
@@ -221,19 +221,19 @@ impl OSCULCTRL_R {
     #[inline(always)]
     pub fn variant(&self) -> OSCULCTRL_A {
         match self.bits {
-            false => OSCULCTRL_A::VALUE1,
-            true => OSCULCTRL_A::VALUE2,
+            false => OSCULCTRL_A::CONST_0,
+            true => OSCULCTRL_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == OSCULCTRL_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == OSCULCTRL_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == OSCULCTRL_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == OSCULCTRL_A::CONST_1
     }
 }
 impl core::ops::Deref for OSCULCTRL_R {
@@ -247,9 +247,9 @@ impl core::ops::Deref for OSCULCTRL_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_CTR_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_CTR_A> for bool {
     #[inline(always)]
@@ -267,19 +267,19 @@ impl RTC_CTR_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_CTR_A {
         match self.bits {
-            false => RTC_CTR_A::VALUE1,
-            true => RTC_CTR_A::VALUE2,
+            false => RTC_CTR_A::CONST_0,
+            true => RTC_CTR_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == RTC_CTR_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == RTC_CTR_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == RTC_CTR_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == RTC_CTR_A::CONST_1
     }
 }
 impl core::ops::Deref for RTC_CTR_R {
@@ -293,9 +293,9 @@ impl core::ops::Deref for RTC_CTR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM0_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_ATIM0_A> for bool {
     #[inline(always)]
@@ -313,19 +313,19 @@ impl RTC_ATIM0_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_ATIM0_A {
         match self.bits {
-            false => RTC_ATIM0_A::VALUE1,
-            true => RTC_ATIM0_A::VALUE2,
+            false => RTC_ATIM0_A::CONST_0,
+            true => RTC_ATIM0_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == RTC_ATIM0_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == RTC_ATIM0_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == RTC_ATIM0_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == RTC_ATIM0_A::CONST_1
     }
 }
 impl core::ops::Deref for RTC_ATIM0_R {
@@ -339,9 +339,9 @@ impl core::ops::Deref for RTC_ATIM0_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM1_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_ATIM1_A> for bool {
     #[inline(always)]
@@ -359,19 +359,19 @@ impl RTC_ATIM1_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_ATIM1_A {
         match self.bits {
-            false => RTC_ATIM1_A::VALUE1,
-            true => RTC_ATIM1_A::VALUE2,
+            false => RTC_ATIM1_A::CONST_0,
+            true => RTC_ATIM1_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == RTC_ATIM1_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == RTC_ATIM1_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == RTC_ATIM1_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == RTC_ATIM1_A::CONST_1
     }
 }
 impl core::ops::Deref for RTC_ATIM1_R {
@@ -385,9 +385,9 @@ impl core::ops::Deref for RTC_ATIM1_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM0_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_TIM0_A> for bool {
     #[inline(always)]
@@ -405,19 +405,19 @@ impl RTC_TIM0_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_TIM0_A {
         match self.bits {
-            false => RTC_TIM0_A::VALUE1,
-            true => RTC_TIM0_A::VALUE2,
+            false => RTC_TIM0_A::CONST_0,
+            true => RTC_TIM0_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == RTC_TIM0_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == RTC_TIM0_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == RTC_TIM0_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == RTC_TIM0_A::CONST_1
     }
 }
 impl core::ops::Deref for RTC_TIM0_R {
@@ -431,9 +431,9 @@ impl core::ops::Deref for RTC_TIM0_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM1_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_TIM1_A> for bool {
     #[inline(always)]
@@ -451,19 +451,19 @@ impl RTC_TIM1_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_TIM1_A {
         match self.bits {
-            false => RTC_TIM1_A::VALUE1,
-            true => RTC_TIM1_A::VALUE2,
+            false => RTC_TIM1_A::CONST_0,
+            true => RTC_TIM1_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == RTC_TIM1_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == RTC_TIM1_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == RTC_TIM1_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == RTC_TIM1_A::CONST_1
     }
 }
 impl core::ops::Deref for RTC_TIM1_R {
@@ -477,9 +477,9 @@ impl core::ops::Deref for RTC_TIM1_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RMX_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RMX_A> for bool {
     #[inline(always)]
@@ -497,19 +497,19 @@ impl RMX_R {
     #[inline(always)]
     pub fn variant(&self) -> RMX_A {
         match self.bits {
-            false => RMX_A::VALUE1,
-            true => RMX_A::VALUE2,
+            false => RMX_A::CONST_0,
+            true => RMX_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == RMX_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == RMX_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == RMX_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == RMX_A::CONST_1
     }
 }
 impl core::ops::Deref for RMX_R {
@@ -523,9 +523,9 @@ impl core::ops::Deref for RMX_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_MSKSR_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_MSKSR_A> for bool {
     #[inline(always)]
@@ -543,19 +543,19 @@ impl RTC_MSKSR_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_MSKSR_A {
         match self.bits {
-            false => RTC_MSKSR_A::VALUE1,
-            true => RTC_MSKSR_A::VALUE2,
+            false => RTC_MSKSR_A::CONST_0,
+            true => RTC_MSKSR_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == RTC_MSKSR_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == RTC_MSKSR_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == RTC_MSKSR_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == RTC_MSKSR_A::CONST_1
     }
 }
 impl core::ops::Deref for RTC_MSKSR_R {
@@ -569,9 +569,9 @@ impl core::ops::Deref for RTC_MSKSR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_CLRSR_A {
     #[doc = "0: Ready"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Busy"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_CLRSR_A> for bool {
     #[inline(always)]
@@ -589,19 +589,19 @@ impl RTC_CLRSR_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_CLRSR_A {
         match self.bits {
-            false => RTC_CLRSR_A::VALUE1,
-            true => RTC_CLRSR_A::VALUE2,
+            false => RTC_CLRSR_A::CONST_0,
+            true => RTC_CLRSR_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == RTC_CLRSR_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == RTC_CLRSR_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == RTC_CLRSR_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == RTC_CLRSR_A::CONST_1
     }
 }
 impl core::ops::Deref for RTC_CLRSR_R {
@@ -611,328 +611,6 @@ impl core::ops::Deref for RTC_CLRSR_R {
         &self.0
     }
 }
-#[doc = "LPACCONF Mirror Register Write Interrupt Set\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACCONF_A {
-    #[doc = "0: Ready"]
-    VALUE1 = 0,
-    #[doc = "1: Busy"]
-    VALUE2 = 1,
-}
-impl From<LPACCONF_A> for bool {
-    #[inline(always)]
-    fn from(variant: LPACCONF_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACCONF` reader - LPACCONF Mirror Register Write Interrupt Set"]
-pub struct LPACCONF_R(crate::FieldReader<bool, LPACCONF_A>);
-impl LPACCONF_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        LPACCONF_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> LPACCONF_A {
-        match self.bits {
-            false => LPACCONF_A::VALUE1,
-            true => LPACCONF_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LPACCONF_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LPACCONF_A::VALUE2
-    }
-}
-impl core::ops::Deref for LPACCONF_R {
-    type Target = crate::FieldReader<bool, LPACCONF_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "LPACTH0 Mirror Register Write Interrupt Set\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACTH0_A {
-    #[doc = "0: Ready"]
-    VALUE1 = 0,
-    #[doc = "1: Busy"]
-    VALUE2 = 1,
-}
-impl From<LPACTH0_A> for bool {
-    #[inline(always)]
-    fn from(variant: LPACTH0_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACTH0` reader - LPACTH0 Mirror Register Write Interrupt Set"]
-pub struct LPACTH0_R(crate::FieldReader<bool, LPACTH0_A>);
-impl LPACTH0_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        LPACTH0_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> LPACTH0_A {
-        match self.bits {
-            false => LPACTH0_A::VALUE1,
-            true => LPACTH0_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LPACTH0_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LPACTH0_A::VALUE2
-    }
-}
-impl core::ops::Deref for LPACTH0_R {
-    type Target = crate::FieldReader<bool, LPACTH0_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "LPACTH1 Mirror Register Write Interrupt Set\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACTH1_A {
-    #[doc = "0: Ready"]
-    VALUE1 = 0,
-    #[doc = "1: Busy"]
-    VALUE2 = 1,
-}
-impl From<LPACTH1_A> for bool {
-    #[inline(always)]
-    fn from(variant: LPACTH1_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACTH1` reader - LPACTH1 Mirror Register Write Interrupt Set"]
-pub struct LPACTH1_R(crate::FieldReader<bool, LPACTH1_A>);
-impl LPACTH1_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        LPACTH1_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> LPACTH1_A {
-        match self.bits {
-            false => LPACTH1_A::VALUE1,
-            true => LPACTH1_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LPACTH1_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LPACTH1_A::VALUE2
-    }
-}
-impl core::ops::Deref for LPACTH1_R {
-    type Target = crate::FieldReader<bool, LPACTH1_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "LPACCLR Mirror Register Write Status\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACCLR_A {
-    #[doc = "0: Ready"]
-    VALUE1 = 0,
-    #[doc = "1: Busy"]
-    VALUE2 = 1,
-}
-impl From<LPACCLR_A> for bool {
-    #[inline(always)]
-    fn from(variant: LPACCLR_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACCLR` reader - LPACCLR Mirror Register Write Status"]
-pub struct LPACCLR_R(crate::FieldReader<bool, LPACCLR_A>);
-impl LPACCLR_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        LPACCLR_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> LPACCLR_A {
-        match self.bits {
-            false => LPACCLR_A::VALUE1,
-            true => LPACCLR_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LPACCLR_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LPACCLR_A::VALUE2
-    }
-}
-impl core::ops::Deref for LPACCLR_R {
-    type Target = crate::FieldReader<bool, LPACCLR_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "LPACSET Mirror Register Write Status\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACSET_A {
-    #[doc = "0: Ready"]
-    VALUE1 = 0,
-    #[doc = "1: Busy"]
-    VALUE2 = 1,
-}
-impl From<LPACSET_A> for bool {
-    #[inline(always)]
-    fn from(variant: LPACSET_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACSET` reader - LPACSET Mirror Register Write Status"]
-pub struct LPACSET_R(crate::FieldReader<bool, LPACSET_A>);
-impl LPACSET_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        LPACSET_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> LPACSET_A {
-        match self.bits {
-            false => LPACSET_A::VALUE1,
-            true => LPACSET_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == LPACSET_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == LPACSET_A::VALUE2
-    }
-}
-impl core::ops::Deref for LPACSET_R {
-    type Target = crate::FieldReader<bool, LPACSET_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "HINTCLR Mirror Register Write Status\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum HINTCLR_A {
-    #[doc = "0: Ready"]
-    VALUE1 = 0,
-    #[doc = "1: Busy"]
-    VALUE2 = 1,
-}
-impl From<HINTCLR_A> for bool {
-    #[inline(always)]
-    fn from(variant: HINTCLR_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `HINTCLR` reader - HINTCLR Mirror Register Write Status"]
-pub struct HINTCLR_R(crate::FieldReader<bool, HINTCLR_A>);
-impl HINTCLR_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        HINTCLR_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> HINTCLR_A {
-        match self.bits {
-            false => HINTCLR_A::VALUE1,
-            true => HINTCLR_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == HINTCLR_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == HINTCLR_A::VALUE2
-    }
-}
-impl core::ops::Deref for HINTCLR_R {
-    type Target = crate::FieldReader<bool, HINTCLR_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "HINTSET Mirror Register Write Status\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum HINTSET_A {
-    #[doc = "0: Ready"]
-    VALUE1 = 0,
-    #[doc = "1: Busy"]
-    VALUE2 = 1,
-}
-impl From<HINTSET_A> for bool {
-    #[inline(always)]
-    fn from(variant: HINTSET_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `HINTSET` reader - HINTSET Mirror Register Write Status"]
-pub struct HINTSET_R(crate::FieldReader<bool, HINTSET_A>);
-impl HINTSET_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        HINTSET_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> HINTSET_A {
-        match self.bits {
-            false => HINTSET_A::VALUE1,
-            true => HINTSET_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == HINTSET_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == HINTSET_A::VALUE2
-    }
-}
-impl core::ops::Deref for HINTSET_R {
-    type Target = crate::FieldReader<bool, HINTSET_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
 impl R {
     #[doc = "Bit 1 - HDCLR Mirror Register Write Status"]
     #[inline(always)]
@@ -999,41 +677,6 @@ impl R {
     pub fn rtc_clrsr(&self) -> RTC_CLRSR_R {
         RTC_CLRSR_R::new(((self.bits >> 15) & 0x01) != 0)
     }
-    #[doc = "Bit 16 - LPACCONF Mirror Register Write Interrupt Set"]
-    #[inline(always)]
-    pub fn lpacconf(&self) -> LPACCONF_R {
-        LPACCONF_R::new(((self.bits >> 16) & 0x01) != 0)
-    }
-    #[doc = "Bit 17 - LPACTH0 Mirror Register Write Interrupt Set"]
-    #[inline(always)]
-    pub fn lpacth0(&self) -> LPACTH0_R {
-        LPACTH0_R::new(((self.bits >> 17) & 0x01) != 0)
-    }
-    #[doc = "Bit 18 - LPACTH1 Mirror Register Write Interrupt Set"]
-    #[inline(always)]
-    pub fn lpacth1(&self) -> LPACTH1_R {
-        LPACTH1_R::new(((self.bits >> 18) & 0x01) != 0)
-    }
-    #[doc = "Bit 20 - LPACCLR Mirror Register Write Status"]
-    #[inline(always)]
-    pub fn lpacclr(&self) -> LPACCLR_R {
-        LPACCLR_R::new(((self.bits >> 20) & 0x01) != 0)
-    }
-    #[doc = "Bit 21 - LPACSET Mirror Register Write Status"]
-    #[inline(always)]
-    pub fn lpacset(&self) -> LPACSET_R {
-        LPACSET_R::new(((self.bits >> 21) & 0x01) != 0)
-    }
-    #[doc = "Bit 23 - HINTCLR Mirror Register Write Status"]
-    #[inline(always)]
-    pub fn hintclr(&self) -> HINTCLR_R {
-        HINTCLR_R::new(((self.bits >> 23) & 0x01) != 0)
-    }
-    #[doc = "Bit 24 - HINTSET Mirror Register Write Status"]
-    #[inline(always)]
-    pub fn hintset(&self) -> HINTSET_R {
-        HINTSET_R::new(((self.bits >> 24) & 0x01) != 0)
-    }
 }
 #[doc = "Mirror Write Status Register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mirrsts](index.html) module"]
 pub struct MIRRSTS_SPEC;
