@@ -38,9 +38,9 @@ impl From<crate::W<NMIREQEN_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PRWARN_A {
     #[doc = "0: Disabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PRWARN_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl PRWARN_R {
     #[inline(always)]
     pub fn variant(&self) -> PRWARN_A {
         match self.bits {
-            false => PRWARN_A::VALUE1,
-            true => PRWARN_A::VALUE2,
+            false => PRWARN_A::CONST_0,
+            true => PRWARN_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PRWARN_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PRWARN_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PRWARN_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PRWARN_A::CONST_1
     }
 }
 impl core::ops::Deref for PRWARN_R {
@@ -92,13 +92,13 @@ impl<'a> PRWARN_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PRWARN_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PRWARN_A::CONST_0)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PRWARN_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PRWARN_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> PRWARN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PI_A {
     #[doc = "0: Disabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PI_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl PI_R {
     #[inline(always)]
     pub fn variant(&self) -> PI_A {
         match self.bits {
-            false => PI_A::VALUE1,
-            true => PI_A::VALUE2,
+            false => PI_A::CONST_0,
+            true => PI_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PI_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PI_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PI_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PI_A::CONST_1
     }
 }
 impl core::ops::Deref for PI_R {
@@ -175,13 +175,13 @@ impl<'a> PI_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PI_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PI_A::CONST_0)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PI_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PI_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> PI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum AI_A {
     #[doc = "0: Disabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<AI_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl AI_R {
     #[inline(always)]
     pub fn variant(&self) -> AI_A {
         match self.bits {
-            false => AI_A::VALUE1,
-            true => AI_A::VALUE2,
+            false => AI_A::CONST_0,
+            true => AI_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == AI_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == AI_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == AI_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == AI_A::CONST_1
     }
 }
 impl core::ops::Deref for AI_R {
@@ -258,13 +258,13 @@ impl<'a> AI_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(AI_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(AI_A::CONST_0)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(AI_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(AI_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> AI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ERU00_A {
     #[doc = "0: Disabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<ERU00_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl ERU00_R {
     #[inline(always)]
     pub fn variant(&self) -> ERU00_A {
         match self.bits {
-            false => ERU00_A::VALUE1,
-            true => ERU00_A::VALUE2,
+            false => ERU00_A::CONST_0,
+            true => ERU00_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == ERU00_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == ERU00_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == ERU00_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == ERU00_A::CONST_1
     }
 }
 impl core::ops::Deref for ERU00_R {
@@ -341,13 +341,13 @@ impl<'a> ERU00_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(ERU00_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(ERU00_A::CONST_0)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(ERU00_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(ERU00_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> ERU00_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ERU01_A {
     #[doc = "0: Disabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<ERU01_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl ERU01_R {
     #[inline(always)]
     pub fn variant(&self) -> ERU01_A {
         match self.bits {
-            false => ERU01_A::VALUE1,
-            true => ERU01_A::VALUE2,
+            false => ERU01_A::CONST_0,
+            true => ERU01_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == ERU01_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == ERU01_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == ERU01_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == ERU01_A::CONST_1
     }
 }
 impl core::ops::Deref for ERU01_R {
@@ -424,13 +424,13 @@ impl<'a> ERU01_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(ERU01_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(ERU01_A::CONST_0)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(ERU01_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(ERU01_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> ERU01_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ERU02_A {
     #[doc = "0: Disabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<ERU02_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl ERU02_R {
     #[inline(always)]
     pub fn variant(&self) -> ERU02_A {
         match self.bits {
-            false => ERU02_A::VALUE1,
-            true => ERU02_A::VALUE2,
+            false => ERU02_A::CONST_0,
+            true => ERU02_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == ERU02_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == ERU02_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == ERU02_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == ERU02_A::CONST_1
     }
 }
 impl core::ops::Deref for ERU02_R {
@@ -507,13 +507,13 @@ impl<'a> ERU02_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(ERU02_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(ERU02_A::CONST_0)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(ERU02_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(ERU02_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> ERU02_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ERU03_A {
     #[doc = "0: Disabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Enabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<ERU03_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl ERU03_R {
     #[inline(always)]
     pub fn variant(&self) -> ERU03_A {
         match self.bits {
-            false => ERU03_A::VALUE1,
-            true => ERU03_A::VALUE2,
+            false => ERU03_A::CONST_0,
+            true => ERU03_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == ERU03_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == ERU03_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == ERU03_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == ERU03_A::CONST_1
     }
 }
 impl core::ops::Deref for ERU03_R {
@@ -590,13 +590,13 @@ impl<'a> ERU03_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(ERU03_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(ERU03_A::CONST_0)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(ERU03_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(ERU03_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
