@@ -23,9 +23,9 @@ impl From<crate::W<SRCLR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PRWARN_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PRWARN_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> PRWARN_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PRWARN_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PRWARN_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PRWARN_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PRWARN_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +74,9 @@ impl<'a> PRWARN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PI_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PI_AW> for bool {
     #[inline(always)]
@@ -96,13 +96,13 @@ impl<'a> PI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PI_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PI_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PI_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PI_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +125,9 @@ impl<'a> PI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum AI_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<AI_AW> for bool {
     #[inline(always)]
@@ -147,13 +147,13 @@ impl<'a> AI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(AI_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(AI_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(AI_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(AI_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -176,9 +176,9 @@ impl<'a> AI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DLROVR_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<DLROVR_AW> for bool {
     #[inline(always)]
@@ -198,13 +198,13 @@ impl<'a> DLROVR_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(DLROVR_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(DLROVR_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(DLROVR_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(DLROVR_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -223,472 +223,13 @@ impl<'a> DLROVR_W<'a> {
         self.w
     }
 }
-#[doc = "LPACLR Mirror Register Update Interrupt Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACCR_AW {
-    #[doc = "0: No effect"]
-    VALUE1 = 0,
-    #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
-}
-impl From<LPACCR_AW> for bool {
-    #[inline(always)]
-    fn from(variant: LPACCR_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACCR` writer - LPACLR Mirror Register Update Interrupt Clear"]
-pub struct LPACCR_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> LPACCR_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LPACCR_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LPACCR_AW::VALUE1)
-    }
-    #[doc = "Clear the status bit"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LPACCR_AW::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
-        self.w
-    }
-}
-#[doc = "LPACTH0 Mirror Register Update Interrupt Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACTH0_AW {
-    #[doc = "0: No effect"]
-    VALUE1 = 0,
-    #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
-}
-impl From<LPACTH0_AW> for bool {
-    #[inline(always)]
-    fn from(variant: LPACTH0_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACTH0` writer - LPACTH0 Mirror Register Update Interrupt Clear"]
-pub struct LPACTH0_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> LPACTH0_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LPACTH0_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LPACTH0_AW::VALUE1)
-    }
-    #[doc = "Clear the status bit"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LPACTH0_AW::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
-        self.w
-    }
-}
-#[doc = "LPACTH1 Mirror Register Update Interrupt Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACTH1_AW {
-    #[doc = "0: No effect"]
-    VALUE1 = 0,
-    #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
-}
-impl From<LPACTH1_AW> for bool {
-    #[inline(always)]
-    fn from(variant: LPACTH1_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACTH1` writer - LPACTH1 Mirror Register Update Interrupt Clear"]
-pub struct LPACTH1_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> LPACTH1_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LPACTH1_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LPACTH1_AW::VALUE1)
-    }
-    #[doc = "Clear the status bit"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LPACTH1_AW::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
-        self.w
-    }
-}
-#[doc = "LPACST Mirror Register Update Interrupt Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACST_AW {
-    #[doc = "0: No effect"]
-    VALUE1 = 0,
-    #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
-}
-impl From<LPACST_AW> for bool {
-    #[inline(always)]
-    fn from(variant: LPACST_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACST` writer - LPACST Mirror Register Update Interrupt Clear"]
-pub struct LPACST_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> LPACST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LPACST_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LPACST_AW::VALUE1)
-    }
-    #[doc = "Clear the status bit"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LPACST_AW::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
-        self.w
-    }
-}
-#[doc = "LPACCLR Mirror Register Update Interrupt Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACCLR_AW {
-    #[doc = "0: No effect"]
-    VALUE1 = 0,
-    #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
-}
-impl From<LPACCLR_AW> for bool {
-    #[inline(always)]
-    fn from(variant: LPACCLR_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACCLR` writer - LPACCLR Mirror Register Update Interrupt Clear"]
-pub struct LPACCLR_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> LPACCLR_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LPACCLR_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LPACCLR_AW::VALUE1)
-    }
-    #[doc = "Clear the status bit"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LPACCLR_AW::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
-        self.w
-    }
-}
-#[doc = "LPACSET Mirror Register Update Interrupt Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum LPACSET_AW {
-    #[doc = "0: No effect"]
-    VALUE1 = 0,
-    #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
-}
-impl From<LPACSET_AW> for bool {
-    #[inline(always)]
-    fn from(variant: LPACSET_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `LPACSET` writer - LPACSET Mirror Register Update Interrupt Clear"]
-pub struct LPACSET_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> LPACSET_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LPACSET_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(LPACSET_AW::VALUE1)
-    }
-    #[doc = "Clear the status bit"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(LPACSET_AW::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
-        self.w
-    }
-}
-#[doc = "HINTST Mirror Register Update Interrupt Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum HINTST_AW {
-    #[doc = "0: No effect"]
-    VALUE1 = 0,
-    #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
-}
-impl From<HINTST_AW> for bool {
-    #[inline(always)]
-    fn from(variant: HINTST_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `HINTST` writer - HINTST Mirror Register Update Interrupt Clear"]
-pub struct HINTST_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> HINTST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: HINTST_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(HINTST_AW::VALUE1)
-    }
-    #[doc = "Clear the status bit"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(HINTST_AW::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
-        self.w
-    }
-}
-#[doc = "HINTCLR Mirror Register Update Interrupt Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum HINTCLR_AW {
-    #[doc = "0: No effect"]
-    VALUE1 = 0,
-    #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
-}
-impl From<HINTCLR_AW> for bool {
-    #[inline(always)]
-    fn from(variant: HINTCLR_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `HINTCLR` writer - HINTCLR Mirror Register Update Interrupt Clear"]
-pub struct HINTCLR_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> HINTCLR_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: HINTCLR_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(HINTCLR_AW::VALUE1)
-    }
-    #[doc = "Clear the status bit"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(HINTCLR_AW::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
-        self.w
-    }
-}
-#[doc = "HINTSET Mirror Register Update Interrupt Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum HINTSET_AW {
-    #[doc = "0: No effect"]
-    VALUE1 = 0,
-    #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
-}
-impl From<HINTSET_AW> for bool {
-    #[inline(always)]
-    fn from(variant: HINTSET_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `HINTSET` writer - HINTSET Mirror Register Update Interrupt Clear"]
-pub struct HINTSET_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> HINTSET_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: HINTSET_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(HINTSET_AW::VALUE1)
-    }
-    #[doc = "Clear the status bit"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(HINTSET_AW::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
-        self.w
-    }
-}
 #[doc = "HDCLR Mirror Register Update Clear\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCLR_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<HDCLR_AW> for bool {
     #[inline(always)]
@@ -708,13 +249,13 @@ impl<'a> HDCLR_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(HDCLR_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(HDCLR_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(HDCLR_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(HDCLR_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -737,9 +278,9 @@ impl<'a> HDCLR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDSET_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<HDSET_AW> for bool {
     #[inline(always)]
@@ -759,13 +300,13 @@ impl<'a> HDSET_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(HDSET_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(HDSET_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(HDSET_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(HDSET_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -788,9 +329,9 @@ impl<'a> HDSET_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCR_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<HDCR_AW> for bool {
     #[inline(always)]
@@ -810,13 +351,13 @@ impl<'a> HDCR_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(HDCR_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(HDCR_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(HDCR_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(HDCR_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -839,9 +380,9 @@ impl<'a> HDCR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCSICTRL_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<OSCSICTRL_AW> for bool {
     #[inline(always)]
@@ -861,13 +402,13 @@ impl<'a> OSCSICTRL_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(OSCSICTRL_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(OSCSICTRL_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(OSCSICTRL_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(OSCSICTRL_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -890,9 +431,9 @@ impl<'a> OSCSICTRL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCULCTRL_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<OSCULCTRL_AW> for bool {
     #[inline(always)]
@@ -912,13 +453,13 @@ impl<'a> OSCULCTRL_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(OSCULCTRL_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(OSCULCTRL_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(OSCULCTRL_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(OSCULCTRL_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -941,9 +482,9 @@ impl<'a> OSCULCTRL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_CTR_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_CTR_AW> for bool {
     #[inline(always)]
@@ -963,13 +504,13 @@ impl<'a> RTC_CTR_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(RTC_CTR_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(RTC_CTR_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(RTC_CTR_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(RTC_CTR_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -992,9 +533,9 @@ impl<'a> RTC_CTR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM0_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_ATIM0_AW> for bool {
     #[inline(always)]
@@ -1014,13 +555,13 @@ impl<'a> RTC_ATIM0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(RTC_ATIM0_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(RTC_ATIM0_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(RTC_ATIM0_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(RTC_ATIM0_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1043,9 +584,9 @@ impl<'a> RTC_ATIM0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM1_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_ATIM1_AW> for bool {
     #[inline(always)]
@@ -1065,13 +606,13 @@ impl<'a> RTC_ATIM1_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(RTC_ATIM1_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(RTC_ATIM1_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(RTC_ATIM1_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(RTC_ATIM1_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1094,9 +635,9 @@ impl<'a> RTC_ATIM1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM0_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_TIM0_AW> for bool {
     #[inline(always)]
@@ -1116,13 +657,13 @@ impl<'a> RTC_TIM0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(RTC_TIM0_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(RTC_TIM0_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(RTC_TIM0_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(RTC_TIM0_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1145,9 +686,9 @@ impl<'a> RTC_TIM0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM1_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RTC_TIM1_AW> for bool {
     #[inline(always)]
@@ -1167,13 +708,13 @@ impl<'a> RTC_TIM1_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(RTC_TIM1_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(RTC_TIM1_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(RTC_TIM1_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(RTC_TIM1_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1196,9 +737,9 @@ impl<'a> RTC_TIM1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RMX_AW {
     #[doc = "0: No effect"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Clear the status bit"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<RMX_AW> for bool {
     #[inline(always)]
@@ -1218,13 +759,13 @@ impl<'a> RMX_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(RMX_AW::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(RMX_AW::CONST_0)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(RMX_AW::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(RMX_AW::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1264,51 +805,6 @@ impl W {
     pub fn dlrovr(&mut self) -> DLROVR_W {
         DLROVR_W { w: self }
     }
-    #[doc = "Bit 6 - LPACLR Mirror Register Update Interrupt Clear"]
-    #[inline(always)]
-    pub fn lpaccr(&mut self) -> LPACCR_W {
-        LPACCR_W { w: self }
-    }
-    #[doc = "Bit 7 - LPACTH0 Mirror Register Update Interrupt Clear"]
-    #[inline(always)]
-    pub fn lpacth0(&mut self) -> LPACTH0_W {
-        LPACTH0_W { w: self }
-    }
-    #[doc = "Bit 8 - LPACTH1 Mirror Register Update Interrupt Clear"]
-    #[inline(always)]
-    pub fn lpacth1(&mut self) -> LPACTH1_W {
-        LPACTH1_W { w: self }
-    }
-    #[doc = "Bit 9 - LPACST Mirror Register Update Interrupt Clear"]
-    #[inline(always)]
-    pub fn lpacst(&mut self) -> LPACST_W {
-        LPACST_W { w: self }
-    }
-    #[doc = "Bit 10 - LPACCLR Mirror Register Update Interrupt Clear"]
-    #[inline(always)]
-    pub fn lpacclr(&mut self) -> LPACCLR_W {
-        LPACCLR_W { w: self }
-    }
-    #[doc = "Bit 11 - LPACSET Mirror Register Update Interrupt Clear"]
-    #[inline(always)]
-    pub fn lpacset(&mut self) -> LPACSET_W {
-        LPACSET_W { w: self }
-    }
-    #[doc = "Bit 12 - HINTST Mirror Register Update Interrupt Clear"]
-    #[inline(always)]
-    pub fn hintst(&mut self) -> HINTST_W {
-        HINTST_W { w: self }
-    }
-    #[doc = "Bit 13 - HINTCLR Mirror Register Update Interrupt Clear"]
-    #[inline(always)]
-    pub fn hintclr(&mut self) -> HINTCLR_W {
-        HINTCLR_W { w: self }
-    }
-    #[doc = "Bit 14 - HINTSET Mirror Register Update Interrupt Clear"]
-    #[inline(always)]
-    pub fn hintset(&mut self) -> HINTSET_W {
-        HINTSET_W { w: self }
-    }
     #[doc = "Bit 17 - HDCLR Mirror Register Update Clear"]
     #[inline(always)]
     pub fn hdclr(&mut self) -> HDCLR_W {
