@@ -38,9 +38,9 @@ impl From<crate::W<PEFLAG_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFPS_A {
     #[doc = "0: No parity error detected"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity error detected"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PEFPS_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl PEFPS_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFPS_A {
         match self.bits {
-            false => PEFPS_A::VALUE1,
-            true => PEFPS_A::VALUE2,
+            false => PEFPS_A::CONST_0,
+            true => PEFPS_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PEFPS_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PEFPS_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PEFPS_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PEFPS_A::CONST_1
     }
 }
 impl core::ops::Deref for PEFPS_R {
@@ -92,13 +92,13 @@ impl<'a> PEFPS_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PEFPS_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEFPS_A::CONST_0)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PEFPS_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEFPS_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> PEFPS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFDS1_A {
     #[doc = "0: No parity error detected"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity error detected"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PEFDS1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl PEFDS1_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFDS1_A {
         match self.bits {
-            false => PEFDS1_A::VALUE1,
-            true => PEFDS1_A::VALUE2,
+            false => PEFDS1_A::CONST_0,
+            true => PEFDS1_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PEFDS1_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PEFDS1_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PEFDS1_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PEFDS1_A::CONST_1
     }
 }
 impl core::ops::Deref for PEFDS1_R {
@@ -175,13 +175,13 @@ impl<'a> PEFDS1_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PEFDS1_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEFDS1_A::CONST_0)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PEFDS1_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEFDS1_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> PEFDS1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFU0_A {
     #[doc = "0: No parity error detected"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity error detected"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PEFU0_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl PEFU0_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFU0_A {
         match self.bits {
-            false => PEFU0_A::VALUE1,
-            true => PEFU0_A::VALUE2,
+            false => PEFU0_A::CONST_0,
+            true => PEFU0_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PEFU0_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PEFU0_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PEFU0_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PEFU0_A::CONST_1
     }
 }
 impl core::ops::Deref for PEFU0_R {
@@ -258,13 +258,13 @@ impl<'a> PEFU0_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PEFU0_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEFU0_A::CONST_0)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PEFU0_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEFU0_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> PEFU0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFU1_A {
     #[doc = "0: No parity error detected"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity error detected"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PEFU1_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl PEFU1_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFU1_A {
         match self.bits {
-            false => PEFU1_A::VALUE1,
-            true => PEFU1_A::VALUE2,
+            false => PEFU1_A::CONST_0,
+            true => PEFU1_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PEFU1_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PEFU1_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PEFU1_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PEFU1_A::CONST_1
     }
 }
 impl core::ops::Deref for PEFU1_R {
@@ -341,13 +341,13 @@ impl<'a> PEFU1_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PEFU1_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEFU1_A::CONST_0)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PEFU1_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEFU1_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> PEFU1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFMC_A {
     #[doc = "0: No parity error detected"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity error detected"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PEFMC_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl PEFMC_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFMC_A {
         match self.bits {
-            false => PEFMC_A::VALUE1,
-            true => PEFMC_A::VALUE2,
+            false => PEFMC_A::CONST_0,
+            true => PEFMC_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PEFMC_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PEFMC_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PEFMC_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PEFMC_A::CONST_1
     }
 }
 impl core::ops::Deref for PEFMC_R {
@@ -424,13 +424,13 @@ impl<'a> PEFMC_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PEFMC_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEFMC_A::CONST_0)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PEFMC_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEFMC_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> PEFMC_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFPPRF_A {
     #[doc = "0: No parity error detected"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity error detected"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PEFPPRF_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl PEFPPRF_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFPPRF_A {
         match self.bits {
-            false => PEFPPRF_A::VALUE1,
-            true => PEFPPRF_A::VALUE2,
+            false => PEFPPRF_A::CONST_0,
+            true => PEFPPRF_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PEFPPRF_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PEFPPRF_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PEFPPRF_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PEFPPRF_A::CONST_1
     }
 }
 impl core::ops::Deref for PEFPPRF_R {
@@ -507,13 +507,13 @@ impl<'a> PEFPPRF_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PEFPPRF_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEFPPRF_A::CONST_0)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PEFPPRF_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEFPPRF_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> PEFPPRF_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEUSB_A {
     #[doc = "0: No parity error detected"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity error detected"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PEUSB_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl PEUSB_R {
     #[inline(always)]
     pub fn variant(&self) -> PEUSB_A {
         match self.bits {
-            false => PEUSB_A::VALUE1,
-            true => PEUSB_A::VALUE2,
+            false => PEUSB_A::CONST_0,
+            true => PEUSB_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PEUSB_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PEUSB_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PEUSB_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PEUSB_A::CONST_1
     }
 }
 impl core::ops::Deref for PEUSB_R {
@@ -590,13 +590,13 @@ impl<'a> PEUSB_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PEUSB_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEUSB_A::CONST_0)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PEUSB_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEUSB_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -615,6 +615,421 @@ impl<'a> PEUSB_W<'a> {
         self.w
     }
 }
+#[doc = "Parity Error Flag for ETH TX Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PEETH0TX_A {
+    #[doc = "0: No parity error detected"]
+    CONST_0 = 0,
+    #[doc = "1: Parity error detected"]
+    CONST_1 = 1,
+}
+impl From<PEETH0TX_A> for bool {
+    #[inline(always)]
+    fn from(variant: PEETH0TX_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PEETH0TX` reader - Parity Error Flag for ETH TX Memory"]
+pub struct PEETH0TX_R(crate::FieldReader<bool, PEETH0TX_A>);
+impl PEETH0TX_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PEETH0TX_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PEETH0TX_A {
+        match self.bits {
+            false => PEETH0TX_A::CONST_0,
+            true => PEETH0TX_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == PEETH0TX_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == PEETH0TX_A::CONST_1
+    }
+}
+impl core::ops::Deref for PEETH0TX_R {
+    type Target = crate::FieldReader<bool, PEETH0TX_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PEETH0TX` writer - Parity Error Flag for ETH TX Memory"]
+pub struct PEETH0TX_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PEETH0TX_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PEETH0TX_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No parity error detected"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEETH0TX_A::CONST_0)
+    }
+    #[doc = "Parity error detected"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEETH0TX_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w
+    }
+}
+#[doc = "Parity Error Flag for ETH RX Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PEETH0RX_A {
+    #[doc = "0: No parity error detected"]
+    CONST_0 = 0,
+    #[doc = "1: Parity error detected"]
+    CONST_1 = 1,
+}
+impl From<PEETH0RX_A> for bool {
+    #[inline(always)]
+    fn from(variant: PEETH0RX_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PEETH0RX` reader - Parity Error Flag for ETH RX Memory"]
+pub struct PEETH0RX_R(crate::FieldReader<bool, PEETH0RX_A>);
+impl PEETH0RX_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PEETH0RX_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PEETH0RX_A {
+        match self.bits {
+            false => PEETH0RX_A::CONST_0,
+            true => PEETH0RX_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == PEETH0RX_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == PEETH0RX_A::CONST_1
+    }
+}
+impl core::ops::Deref for PEETH0RX_R {
+    type Target = crate::FieldReader<bool, PEETH0RX_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PEETH0RX` writer - Parity Error Flag for ETH RX Memory"]
+pub struct PEETH0RX_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PEETH0RX_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PEETH0RX_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No parity error detected"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEETH0RX_A::CONST_0)
+    }
+    #[doc = "Parity error detected"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEETH0RX_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w
+    }
+}
+#[doc = "Parity Error Flag for SDMMC Memory 0\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PESD0_A {
+    #[doc = "0: No parity error detected"]
+    CONST_0 = 0,
+    #[doc = "1: Parity error detected"]
+    CONST_1 = 1,
+}
+impl From<PESD0_A> for bool {
+    #[inline(always)]
+    fn from(variant: PESD0_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PESD0` reader - Parity Error Flag for SDMMC Memory 0"]
+pub struct PESD0_R(crate::FieldReader<bool, PESD0_A>);
+impl PESD0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PESD0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PESD0_A {
+        match self.bits {
+            false => PESD0_A::CONST_0,
+            true => PESD0_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == PESD0_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == PESD0_A::CONST_1
+    }
+}
+impl core::ops::Deref for PESD0_R {
+    type Target = crate::FieldReader<bool, PESD0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PESD0` writer - Parity Error Flag for SDMMC Memory 0"]
+pub struct PESD0_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PESD0_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PESD0_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No parity error detected"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PESD0_A::CONST_0)
+    }
+    #[doc = "Parity error detected"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PESD0_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w
+    }
+}
+#[doc = "Parity Error Flag for SDMMC Memory 1\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PESD1_A {
+    #[doc = "0: No parity error detected"]
+    CONST_0 = 0,
+    #[doc = "1: Parity error detected"]
+    CONST_1 = 1,
+}
+impl From<PESD1_A> for bool {
+    #[inline(always)]
+    fn from(variant: PESD1_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PESD1` reader - Parity Error Flag for SDMMC Memory 1"]
+pub struct PESD1_R(crate::FieldReader<bool, PESD1_A>);
+impl PESD1_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PESD1_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PESD1_A {
+        match self.bits {
+            false => PESD1_A::CONST_0,
+            true => PESD1_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == PESD1_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == PESD1_A::CONST_1
+    }
+}
+impl core::ops::Deref for PESD1_R {
+    type Target = crate::FieldReader<bool, PESD1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PESD1` writer - Parity Error Flag for SDMMC Memory 1"]
+pub struct PESD1_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PESD1_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PESD1_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No parity error detected"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PESD1_A::CONST_0)
+    }
+    #[doc = "Parity error detected"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PESD1_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w
+    }
+}
+#[doc = "Parity Error Flag for ECAT0 Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PEECAT0_A {
+    #[doc = "0: No parity error detected"]
+    CONST_0 = 0,
+    #[doc = "1: Parity error detected"]
+    CONST_1 = 1,
+}
+impl From<PEECAT0_A> for bool {
+    #[inline(always)]
+    fn from(variant: PEECAT0_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PEECAT0` reader - Parity Error Flag for ECAT0 Memory"]
+pub struct PEECAT0_R(crate::FieldReader<bool, PEECAT0_A>);
+impl PEECAT0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PEECAT0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PEECAT0_A {
+        match self.bits {
+            false => PEECAT0_A::CONST_0,
+            true => PEECAT0_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == PEECAT0_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == PEECAT0_A::CONST_1
+    }
+}
+impl core::ops::Deref for PEECAT0_R {
+    type Target = crate::FieldReader<bool, PEECAT0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PEECAT0` writer - Parity Error Flag for ECAT0 Memory"]
+pub struct PEECAT0_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PEECAT0_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PEECAT0_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No parity error detected"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PEECAT0_A::CONST_0)
+    }
+    #[doc = "Parity error detected"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PEECAT0_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w
+    }
+}
 impl R {
     #[doc = "Bit 0 - Parity Error Flag for PSRAM"]
     #[inline(always)]
@@ -651,6 +1066,31 @@ impl R {
     pub fn peusb(&self) -> PEUSB_R {
         PEUSB_R::new(((self.bits >> 16) & 0x01) != 0)
     }
+    #[doc = "Bit 17 - Parity Error Flag for ETH TX Memory"]
+    #[inline(always)]
+    pub fn peeth0tx(&self) -> PEETH0TX_R {
+        PEETH0TX_R::new(((self.bits >> 17) & 0x01) != 0)
+    }
+    #[doc = "Bit 18 - Parity Error Flag for ETH RX Memory"]
+    #[inline(always)]
+    pub fn peeth0rx(&self) -> PEETH0RX_R {
+        PEETH0RX_R::new(((self.bits >> 18) & 0x01) != 0)
+    }
+    #[doc = "Bit 19 - Parity Error Flag for SDMMC Memory 0"]
+    #[inline(always)]
+    pub fn pesd0(&self) -> PESD0_R {
+        PESD0_R::new(((self.bits >> 19) & 0x01) != 0)
+    }
+    #[doc = "Bit 20 - Parity Error Flag for SDMMC Memory 1"]
+    #[inline(always)]
+    pub fn pesd1(&self) -> PESD1_R {
+        PESD1_R::new(((self.bits >> 20) & 0x01) != 0)
+    }
+    #[doc = "Bit 24 - Parity Error Flag for ECAT0 Memory"]
+    #[inline(always)]
+    pub fn peecat0(&self) -> PEECAT0_R {
+        PEECAT0_R::new(((self.bits >> 24) & 0x01) != 0)
+    }
 }
 impl W {
     #[doc = "Bit 0 - Parity Error Flag for PSRAM"]
@@ -688,6 +1128,31 @@ impl W {
     pub fn peusb(&mut self) -> PEUSB_W {
         PEUSB_W { w: self }
     }
+    #[doc = "Bit 17 - Parity Error Flag for ETH TX Memory"]
+    #[inline(always)]
+    pub fn peeth0tx(&mut self) -> PEETH0TX_W {
+        PEETH0TX_W { w: self }
+    }
+    #[doc = "Bit 18 - Parity Error Flag for ETH RX Memory"]
+    #[inline(always)]
+    pub fn peeth0rx(&mut self) -> PEETH0RX_W {
+        PEETH0RX_W { w: self }
+    }
+    #[doc = "Bit 19 - Parity Error Flag for SDMMC Memory 0"]
+    #[inline(always)]
+    pub fn pesd0(&mut self) -> PESD0_W {
+        PESD0_W { w: self }
+    }
+    #[doc = "Bit 20 - Parity Error Flag for SDMMC Memory 1"]
+    #[inline(always)]
+    pub fn pesd1(&mut self) -> PESD1_W {
+        PESD1_W { w: self }
+    }
+    #[doc = "Bit 24 - Parity Error Flag for ECAT0 Memory"]
+    #[inline(always)]
+    pub fn peecat0(&mut self) -> PEECAT0_W {
+        PEECAT0_W { w: self }
+    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
