@@ -38,9 +38,9 @@ impl From<crate::W<PMTSR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTENPS_A {
     #[doc = "0: Standard operation"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity bits under test"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<MTENPS_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl MTENPS_R {
     #[inline(always)]
     pub fn variant(&self) -> MTENPS_A {
         match self.bits {
-            false => MTENPS_A::VALUE1,
-            true => MTENPS_A::VALUE2,
+            false => MTENPS_A::CONST_0,
+            true => MTENPS_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == MTENPS_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == MTENPS_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == MTENPS_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == MTENPS_A::CONST_1
     }
 }
 impl core::ops::Deref for MTENPS_R {
@@ -92,13 +92,13 @@ impl<'a> MTENPS_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(MTENPS_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTENPS_A::CONST_0)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(MTENPS_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTENPS_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> MTENPS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTENDS1_A {
     #[doc = "0: Standard operation"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity bits under test"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<MTENDS1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl MTENDS1_R {
     #[inline(always)]
     pub fn variant(&self) -> MTENDS1_A {
         match self.bits {
-            false => MTENDS1_A::VALUE1,
-            true => MTENDS1_A::VALUE2,
+            false => MTENDS1_A::CONST_0,
+            true => MTENDS1_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == MTENDS1_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == MTENDS1_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == MTENDS1_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == MTENDS1_A::CONST_1
     }
 }
 impl core::ops::Deref for MTENDS1_R {
@@ -175,13 +175,13 @@ impl<'a> MTENDS1_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(MTENDS1_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTENDS1_A::CONST_0)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(MTENDS1_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTENDS1_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> MTENDS1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTEU0_A {
     #[doc = "0: Standard operation"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity bits under test"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<MTEU0_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl MTEU0_R {
     #[inline(always)]
     pub fn variant(&self) -> MTEU0_A {
         match self.bits {
-            false => MTEU0_A::VALUE1,
-            true => MTEU0_A::VALUE2,
+            false => MTEU0_A::CONST_0,
+            true => MTEU0_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == MTEU0_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == MTEU0_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == MTEU0_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == MTEU0_A::CONST_1
     }
 }
 impl core::ops::Deref for MTEU0_R {
@@ -258,13 +258,13 @@ impl<'a> MTEU0_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(MTEU0_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTEU0_A::CONST_0)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(MTEU0_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTEU0_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> MTEU0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTEU1_A {
     #[doc = "0: Standard operation"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity bits under test"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<MTEU1_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl MTEU1_R {
     #[inline(always)]
     pub fn variant(&self) -> MTEU1_A {
         match self.bits {
-            false => MTEU1_A::VALUE1,
-            true => MTEU1_A::VALUE2,
+            false => MTEU1_A::CONST_0,
+            true => MTEU1_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == MTEU1_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == MTEU1_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == MTEU1_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == MTEU1_A::CONST_1
     }
 }
 impl core::ops::Deref for MTEU1_R {
@@ -341,13 +341,13 @@ impl<'a> MTEU1_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(MTEU1_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTEU1_A::CONST_0)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(MTEU1_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTEU1_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> MTEU1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTEMC_A {
     #[doc = "0: Standard operation"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity bits under test"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<MTEMC_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl MTEMC_R {
     #[inline(always)]
     pub fn variant(&self) -> MTEMC_A {
         match self.bits {
-            false => MTEMC_A::VALUE1,
-            true => MTEMC_A::VALUE2,
+            false => MTEMC_A::CONST_0,
+            true => MTEMC_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == MTEMC_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == MTEMC_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == MTEMC_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == MTEMC_A::CONST_1
     }
 }
 impl core::ops::Deref for MTEMC_R {
@@ -424,13 +424,13 @@ impl<'a> MTEMC_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(MTEMC_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTEMC_A::CONST_0)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(MTEMC_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTEMC_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> MTEMC_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTEPPRF_A {
     #[doc = "0: Standard operation"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity bits under test"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<MTEPPRF_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl MTEPPRF_R {
     #[inline(always)]
     pub fn variant(&self) -> MTEPPRF_A {
         match self.bits {
-            false => MTEPPRF_A::VALUE1,
-            true => MTEPPRF_A::VALUE2,
+            false => MTEPPRF_A::CONST_0,
+            true => MTEPPRF_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == MTEPPRF_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == MTEPPRF_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == MTEPPRF_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == MTEPPRF_A::CONST_1
     }
 }
 impl core::ops::Deref for MTEPPRF_R {
@@ -507,13 +507,13 @@ impl<'a> MTEPPRF_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(MTEPPRF_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTEPPRF_A::CONST_0)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(MTEPPRF_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTEPPRF_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> MTEPPRF_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTUSB_A {
     #[doc = "0: Standard operation"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Parity bits under test"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<MTUSB_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl MTUSB_R {
     #[inline(always)]
     pub fn variant(&self) -> MTUSB_A {
         match self.bits {
-            false => MTUSB_A::VALUE1,
-            true => MTUSB_A::VALUE2,
+            false => MTUSB_A::CONST_0,
+            true => MTUSB_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == MTUSB_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == MTUSB_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == MTUSB_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == MTUSB_A::CONST_1
     }
 }
 impl core::ops::Deref for MTUSB_R {
@@ -590,13 +590,13 @@ impl<'a> MTUSB_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(MTUSB_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTUSB_A::CONST_0)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(MTUSB_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTUSB_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -615,6 +615,421 @@ impl<'a> MTUSB_W<'a> {
         self.w
     }
 }
+#[doc = "Test Enable Control for ETH TX Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTETH0TX_A {
+    #[doc = "0: Standard operation"]
+    CONST_0 = 0,
+    #[doc = "1: Parity bits under test"]
+    CONST_1 = 1,
+}
+impl From<MTETH0TX_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTETH0TX_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `MTETH0TX` reader - Test Enable Control for ETH TX Memory"]
+pub struct MTETH0TX_R(crate::FieldReader<bool, MTETH0TX_A>);
+impl MTETH0TX_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTETH0TX_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTETH0TX_A {
+        match self.bits {
+            false => MTETH0TX_A::CONST_0,
+            true => MTETH0TX_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == MTETH0TX_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == MTETH0TX_A::CONST_1
+    }
+}
+impl core::ops::Deref for MTETH0TX_R {
+    type Target = crate::FieldReader<bool, MTETH0TX_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MTETH0TX` writer - Test Enable Control for ETH TX Memory"]
+pub struct MTETH0TX_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> MTETH0TX_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: MTETH0TX_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Standard operation"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTETH0TX_A::CONST_0)
+    }
+    #[doc = "Parity bits under test"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTETH0TX_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w
+    }
+}
+#[doc = "Test Enable Control for ETH RX Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTETH0RX_A {
+    #[doc = "0: Standard operation"]
+    CONST_0 = 0,
+    #[doc = "1: Parity bits under test"]
+    CONST_1 = 1,
+}
+impl From<MTETH0RX_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTETH0RX_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `MTETH0RX` reader - Test Enable Control for ETH RX Memory"]
+pub struct MTETH0RX_R(crate::FieldReader<bool, MTETH0RX_A>);
+impl MTETH0RX_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTETH0RX_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTETH0RX_A {
+        match self.bits {
+            false => MTETH0RX_A::CONST_0,
+            true => MTETH0RX_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == MTETH0RX_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == MTETH0RX_A::CONST_1
+    }
+}
+impl core::ops::Deref for MTETH0RX_R {
+    type Target = crate::FieldReader<bool, MTETH0RX_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MTETH0RX` writer - Test Enable Control for ETH RX Memory"]
+pub struct MTETH0RX_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> MTETH0RX_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: MTETH0RX_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Standard operation"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTETH0RX_A::CONST_0)
+    }
+    #[doc = "Parity bits under test"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTETH0RX_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w
+    }
+}
+#[doc = "Test Enable Control for SDMMC Memory 0\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTSD0_A {
+    #[doc = "0: Standard operation"]
+    CONST_0 = 0,
+    #[doc = "1: Parity bits under test"]
+    CONST_1 = 1,
+}
+impl From<MTSD0_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTSD0_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `MTSD0` reader - Test Enable Control for SDMMC Memory 0"]
+pub struct MTSD0_R(crate::FieldReader<bool, MTSD0_A>);
+impl MTSD0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTSD0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTSD0_A {
+        match self.bits {
+            false => MTSD0_A::CONST_0,
+            true => MTSD0_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == MTSD0_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == MTSD0_A::CONST_1
+    }
+}
+impl core::ops::Deref for MTSD0_R {
+    type Target = crate::FieldReader<bool, MTSD0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MTSD0` writer - Test Enable Control for SDMMC Memory 0"]
+pub struct MTSD0_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> MTSD0_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: MTSD0_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Standard operation"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTSD0_A::CONST_0)
+    }
+    #[doc = "Parity bits under test"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTSD0_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w
+    }
+}
+#[doc = "Test Enable Control for SDMMC Memory 1\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTSD1_A {
+    #[doc = "0: Standard operation"]
+    CONST_0 = 0,
+    #[doc = "1: Parity bits under test"]
+    CONST_1 = 1,
+}
+impl From<MTSD1_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTSD1_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `MTSD1` reader - Test Enable Control for SDMMC Memory 1"]
+pub struct MTSD1_R(crate::FieldReader<bool, MTSD1_A>);
+impl MTSD1_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTSD1_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTSD1_A {
+        match self.bits {
+            false => MTSD1_A::CONST_0,
+            true => MTSD1_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == MTSD1_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == MTSD1_A::CONST_1
+    }
+}
+impl core::ops::Deref for MTSD1_R {
+    type Target = crate::FieldReader<bool, MTSD1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MTSD1` writer - Test Enable Control for SDMMC Memory 1"]
+pub struct MTSD1_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> MTSD1_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: MTSD1_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Standard operation"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTSD1_A::CONST_0)
+    }
+    #[doc = "Parity bits under test"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTSD1_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w
+    }
+}
+#[doc = "Test Enable Control for ECAT0 Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTECAT0_A {
+    #[doc = "0: Standard operation"]
+    CONST_0 = 0,
+    #[doc = "1: Parity bits under test"]
+    CONST_1 = 1,
+}
+impl From<MTECAT0_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTECAT0_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `MTECAT0` reader - Test Enable Control for ECAT0 Memory"]
+pub struct MTECAT0_R(crate::FieldReader<bool, MTECAT0_A>);
+impl MTECAT0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTECAT0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTECAT0_A {
+        match self.bits {
+            false => MTECAT0_A::CONST_0,
+            true => MTECAT0_A::CONST_1,
+        }
+    }
+    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[inline(always)]
+    pub fn is_const_0(&self) -> bool {
+        **self == MTECAT0_A::CONST_0
+    }
+    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[inline(always)]
+    pub fn is_const_1(&self) -> bool {
+        **self == MTECAT0_A::CONST_1
+    }
+}
+impl core::ops::Deref for MTECAT0_R {
+    type Target = crate::FieldReader<bool, MTECAT0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MTECAT0` writer - Test Enable Control for ECAT0 Memory"]
+pub struct MTECAT0_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> MTECAT0_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: MTECAT0_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Standard operation"]
+    #[inline(always)]
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(MTECAT0_A::CONST_0)
+    }
+    #[doc = "Parity bits under test"]
+    #[inline(always)]
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(MTECAT0_A::CONST_1)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w
+    }
+}
 impl R {
     #[doc = "Bit 0 - Test Enable Control for PSRAM"]
     #[inline(always)]
@@ -651,6 +1066,31 @@ impl R {
     pub fn mtusb(&self) -> MTUSB_R {
         MTUSB_R::new(((self.bits >> 16) & 0x01) != 0)
     }
+    #[doc = "Bit 17 - Test Enable Control for ETH TX Memory"]
+    #[inline(always)]
+    pub fn mteth0tx(&self) -> MTETH0TX_R {
+        MTETH0TX_R::new(((self.bits >> 17) & 0x01) != 0)
+    }
+    #[doc = "Bit 18 - Test Enable Control for ETH RX Memory"]
+    #[inline(always)]
+    pub fn mteth0rx(&self) -> MTETH0RX_R {
+        MTETH0RX_R::new(((self.bits >> 18) & 0x01) != 0)
+    }
+    #[doc = "Bit 19 - Test Enable Control for SDMMC Memory 0"]
+    #[inline(always)]
+    pub fn mtsd0(&self) -> MTSD0_R {
+        MTSD0_R::new(((self.bits >> 19) & 0x01) != 0)
+    }
+    #[doc = "Bit 20 - Test Enable Control for SDMMC Memory 1"]
+    #[inline(always)]
+    pub fn mtsd1(&self) -> MTSD1_R {
+        MTSD1_R::new(((self.bits >> 20) & 0x01) != 0)
+    }
+    #[doc = "Bit 24 - Test Enable Control for ECAT0 Memory"]
+    #[inline(always)]
+    pub fn mtecat0(&self) -> MTECAT0_R {
+        MTECAT0_R::new(((self.bits >> 24) & 0x01) != 0)
+    }
 }
 impl W {
     #[doc = "Bit 0 - Test Enable Control for PSRAM"]
@@ -688,6 +1128,31 @@ impl W {
     pub fn mtusb(&mut self) -> MTUSB_W {
         MTUSB_W { w: self }
     }
+    #[doc = "Bit 17 - Test Enable Control for ETH TX Memory"]
+    #[inline(always)]
+    pub fn mteth0tx(&mut self) -> MTETH0TX_W {
+        MTETH0TX_W { w: self }
+    }
+    #[doc = "Bit 18 - Test Enable Control for ETH RX Memory"]
+    #[inline(always)]
+    pub fn mteth0rx(&mut self) -> MTETH0RX_W {
+        MTETH0RX_W { w: self }
+    }
+    #[doc = "Bit 19 - Test Enable Control for SDMMC Memory 0"]
+    #[inline(always)]
+    pub fn mtsd0(&mut self) -> MTSD0_W {
+        MTSD0_W { w: self }
+    }
+    #[doc = "Bit 20 - Test Enable Control for SDMMC Memory 1"]
+    #[inline(always)]
+    pub fn mtsd1(&mut self) -> MTSD1_W {
+        MTSD1_W { w: self }
+    }
+    #[doc = "Bit 24 - Test Enable Control for ECAT0 Memory"]
+    #[inline(always)]
+    pub fn mtecat0(&mut self) -> MTECAT0_W {
+        MTECAT0_W { w: self }
+    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
