@@ -38,9 +38,9 @@ impl From<crate::W<USBPLLCON_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum VCOBYP_A {
     #[doc = "0: Normal operation, VCO is not bypassed"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Prescaler Mode, VCO is bypassed"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<VCOBYP_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl VCOBYP_R {
     #[inline(always)]
     pub fn variant(&self) -> VCOBYP_A {
         match self.bits {
-            false => VCOBYP_A::VALUE1,
-            true => VCOBYP_A::VALUE2,
+            false => VCOBYP_A::CONST_0,
+            true => VCOBYP_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == VCOBYP_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == VCOBYP_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == VCOBYP_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == VCOBYP_A::CONST_1
     }
 }
 impl core::ops::Deref for VCOBYP_R {
@@ -92,13 +92,13 @@ impl<'a> VCOBYP_W<'a> {
     }
     #[doc = "Normal operation, VCO is not bypassed"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(VCOBYP_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(VCOBYP_A::CONST_0)
     }
     #[doc = "Prescaler Mode, VCO is bypassed"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(VCOBYP_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(VCOBYP_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> VCOBYP_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum VCOPWD_A {
     #[doc = "0: Normal behavior"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: The VCO is put into a Power Saving Mode"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<VCOPWD_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl VCOPWD_R {
     #[inline(always)]
     pub fn variant(&self) -> VCOPWD_A {
         match self.bits {
-            false => VCOPWD_A::VALUE1,
-            true => VCOPWD_A::VALUE2,
+            false => VCOPWD_A::CONST_0,
+            true => VCOPWD_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == VCOPWD_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == VCOPWD_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == VCOPWD_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == VCOPWD_A::CONST_1
     }
 }
 impl core::ops::Deref for VCOPWD_R {
@@ -175,13 +175,13 @@ impl<'a> VCOPWD_W<'a> {
     }
     #[doc = "Normal behavior"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(VCOPWD_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(VCOPWD_A::CONST_0)
     }
     #[doc = "The VCO is put into a Power Saving Mode"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(VCOPWD_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(VCOPWD_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> VCOPWD_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum VCOTR_A {
     #[doc = "0: VCO bandwidth is operating in the normal range. VCO output frequency is between 260 and 520 MHz for a input frequency between 8 and 16 MHz."]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: VCO bandwidth is operating in the test range. VCO output frequency is between 260 and 520 MHz for a input frequency between 8 and 16 MHz."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<VCOTR_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl VCOTR_R {
     #[inline(always)]
     pub fn variant(&self) -> VCOTR_A {
         match self.bits {
-            false => VCOTR_A::VALUE1,
-            true => VCOTR_A::VALUE2,
+            false => VCOTR_A::CONST_0,
+            true => VCOTR_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == VCOTR_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == VCOTR_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == VCOTR_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == VCOTR_A::CONST_1
     }
 }
 impl core::ops::Deref for VCOTR_R {
@@ -258,13 +258,13 @@ impl<'a> VCOTR_W<'a> {
     }
     #[doc = "VCO bandwidth is operating in the normal range. VCO output frequency is between 260 and 520 MHz for a input frequency between 8 and 16 MHz."]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(VCOTR_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(VCOTR_A::CONST_0)
     }
     #[doc = "VCO bandwidth is operating in the test range. VCO output frequency is between 260 and 520 MHz for a input frequency between 8 and 16 MHz."]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(VCOTR_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(VCOTR_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> VCOTR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum FINDIS_A {
     #[doc = "0: Connect oscillator to the VCO part"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Disconnect oscillator from the VCO part."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<FINDIS_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl FINDIS_R {
     #[inline(always)]
     pub fn variant(&self) -> FINDIS_A {
         match self.bits {
-            false => FINDIS_A::VALUE1,
-            true => FINDIS_A::VALUE2,
+            false => FINDIS_A::CONST_0,
+            true => FINDIS_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == FINDIS_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == FINDIS_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == FINDIS_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == FINDIS_A::CONST_1
     }
 }
 impl core::ops::Deref for FINDIS_R {
@@ -341,13 +341,13 @@ impl<'a> FINDIS_W<'a> {
     }
     #[doc = "Connect oscillator to the VCO part"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(FINDIS_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(FINDIS_A::CONST_0)
     }
     #[doc = "Disconnect oscillator from the VCO part."]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(FINDIS_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(FINDIS_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> FINDIS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCDISCDIS_A {
     #[doc = "0: In case of a PLL loss-of-lock bit FINDIS is set"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: In case of a PLL loss-of-lock bit FINDIS is cleared"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<OSCDISCDIS_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl OSCDISCDIS_R {
     #[inline(always)]
     pub fn variant(&self) -> OSCDISCDIS_A {
         match self.bits {
-            false => OSCDISCDIS_A::VALUE1,
-            true => OSCDISCDIS_A::VALUE2,
+            false => OSCDISCDIS_A::CONST_0,
+            true => OSCDISCDIS_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == OSCDISCDIS_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == OSCDISCDIS_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == OSCDISCDIS_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == OSCDISCDIS_A::CONST_1
     }
 }
 impl core::ops::Deref for OSCDISCDIS_R {
@@ -424,13 +424,13 @@ impl<'a> OSCDISCDIS_W<'a> {
     }
     #[doc = "In case of a PLL loss-of-lock bit FINDIS is set"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(OSCDISCDIS_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(OSCDISCDIS_A::CONST_0)
     }
     #[doc = "In case of a PLL loss-of-lock bit FINDIS is cleared"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(OSCDISCDIS_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(OSCDISCDIS_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -479,9 +479,9 @@ impl<'a> NDIV_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PLLPWD_A {
     #[doc = "0: Normal behavior"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: The complete PLL block is put into a Power Saving Mode. Only the Bypass Mode is active if previously selected."]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PLLPWD_A> for bool {
     #[inline(always)]
@@ -499,19 +499,19 @@ impl PLLPWD_R {
     #[inline(always)]
     pub fn variant(&self) -> PLLPWD_A {
         match self.bits {
-            false => PLLPWD_A::VALUE1,
-            true => PLLPWD_A::VALUE2,
+            false => PLLPWD_A::CONST_0,
+            true => PLLPWD_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PLLPWD_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PLLPWD_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PLLPWD_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PLLPWD_A::CONST_1
     }
 }
 impl core::ops::Deref for PLLPWD_R {
@@ -533,13 +533,13 @@ impl<'a> PLLPWD_W<'a> {
     }
     #[doc = "Normal behavior"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PLLPWD_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PLLPWD_A::CONST_0)
     }
     #[doc = "The complete PLL block is put into a Power Saving Mode. Only the Bypass Mode is active if previously selected."]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PLLPWD_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PLLPWD_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
