@@ -34,13 +34,13 @@ impl From<crate::W<TRAPDIS_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "System OSC WDT Trap Disable\n\nValue on reset: 1"]
+#[doc = "OSC_HP Oscillator Watchdog Trap Disable\n\nValue on reset: 1"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SOSCWDGT_A {
     #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<SOSCWDGT_A> for bool {
     #[inline(always)]
@@ -48,7 +48,7 @@ impl From<SOSCWDGT_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `SOSCWDGT` reader - System OSC WDT Trap Disable"]
+#[doc = "Field `SOSCWDGT` reader - OSC_HP Oscillator Watchdog Trap Disable"]
 pub struct SOSCWDGT_R(crate::FieldReader<bool, SOSCWDGT_A>);
 impl SOSCWDGT_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -58,19 +58,19 @@ impl SOSCWDGT_R {
     #[inline(always)]
     pub fn variant(&self) -> SOSCWDGT_A {
         match self.bits {
-            false => SOSCWDGT_A::VALUE1,
-            true => SOSCWDGT_A::VALUE2,
+            false => SOSCWDGT_A::CONST_0,
+            true => SOSCWDGT_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == SOSCWDGT_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == SOSCWDGT_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == SOSCWDGT_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == SOSCWDGT_A::CONST_1
     }
 }
 impl core::ops::Deref for SOSCWDGT_R {
@@ -80,7 +80,7 @@ impl core::ops::Deref for SOSCWDGT_R {
         &self.0
     }
 }
-#[doc = "Field `SOSCWDGT` writer - System OSC WDT Trap Disable"]
+#[doc = "Field `SOSCWDGT` writer - OSC_HP Oscillator Watchdog Trap Disable"]
 pub struct SOSCWDGT_W<'a> {
     w: &'a mut W,
 }
@@ -92,13 +92,13 @@ impl<'a> SOSCWDGT_W<'a> {
     }
     #[doc = "Trap request enabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(SOSCWDGT_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(SOSCWDGT_A::CONST_0)
     }
     #[doc = "Trap request disabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(SOSCWDGT_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(SOSCWDGT_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> SOSCWDGT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SVCOLCKT_A {
     #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<SVCOLCKT_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl SVCOLCKT_R {
     #[inline(always)]
     pub fn variant(&self) -> SVCOLCKT_A {
         match self.bits {
-            false => SVCOLCKT_A::VALUE1,
-            true => SVCOLCKT_A::VALUE2,
+            false => SVCOLCKT_A::CONST_0,
+            true => SVCOLCKT_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == SVCOLCKT_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == SVCOLCKT_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == SVCOLCKT_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == SVCOLCKT_A::CONST_1
     }
 }
 impl core::ops::Deref for SVCOLCKT_R {
@@ -175,13 +175,13 @@ impl<'a> SVCOLCKT_W<'a> {
     }
     #[doc = "Trap request enabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(SVCOLCKT_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(SVCOLCKT_A::CONST_0)
     }
     #[doc = "Trap request disabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(SVCOLCKT_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(SVCOLCKT_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> SVCOLCKT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum UVCOLCKT_A {
     #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<UVCOLCKT_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl UVCOLCKT_R {
     #[inline(always)]
     pub fn variant(&self) -> UVCOLCKT_A {
         match self.bits {
-            false => UVCOLCKT_A::VALUE1,
-            true => UVCOLCKT_A::VALUE2,
+            false => UVCOLCKT_A::CONST_0,
+            true => UVCOLCKT_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == UVCOLCKT_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == UVCOLCKT_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == UVCOLCKT_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == UVCOLCKT_A::CONST_1
     }
 }
 impl core::ops::Deref for UVCOLCKT_R {
@@ -258,13 +258,13 @@ impl<'a> UVCOLCKT_W<'a> {
     }
     #[doc = "Trap request enabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(UVCOLCKT_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(UVCOLCKT_A::CONST_0)
     }
     #[doc = "Trap request disabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(UVCOLCKT_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(UVCOLCKT_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> UVCOLCKT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PET_A {
     #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<PET_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl PET_R {
     #[inline(always)]
     pub fn variant(&self) -> PET_A {
         match self.bits {
-            false => PET_A::VALUE1,
-            true => PET_A::VALUE2,
+            false => PET_A::CONST_0,
+            true => PET_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == PET_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == PET_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == PET_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == PET_A::CONST_1
     }
 }
 impl core::ops::Deref for PET_R {
@@ -341,13 +341,13 @@ impl<'a> PET_W<'a> {
     }
     #[doc = "Trap request enabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(PET_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(PET_A::CONST_0)
     }
     #[doc = "Trap request disabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(PET_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(PET_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> PET_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum BRWNT_A {
     #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<BRWNT_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl BRWNT_R {
     #[inline(always)]
     pub fn variant(&self) -> BRWNT_A {
         match self.bits {
-            false => BRWNT_A::VALUE1,
-            true => BRWNT_A::VALUE2,
+            false => BRWNT_A::CONST_0,
+            true => BRWNT_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == BRWNT_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == BRWNT_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == BRWNT_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == BRWNT_A::CONST_1
     }
 }
 impl core::ops::Deref for BRWNT_R {
@@ -424,13 +424,13 @@ impl<'a> BRWNT_W<'a> {
     }
     #[doc = "Trap request enabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(BRWNT_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(BRWNT_A::CONST_0)
     }
     #[doc = "Trap request disabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(BRWNT_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(BRWNT_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -449,13 +449,13 @@ impl<'a> BRWNT_W<'a> {
         self.w
     }
 }
-#[doc = "Wake-up Trap Disable\n\nValue on reset: 1"]
+#[doc = "OSC_ULP Oscillator Watchdog Trap Disable\n\nValue on reset: 1"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ULPWDGT_A {
     #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<ULPWDGT_A> for bool {
     #[inline(always)]
@@ -463,7 +463,7 @@ impl From<ULPWDGT_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `ULPWDGT` reader - Wake-up Trap Disable"]
+#[doc = "Field `ULPWDGT` reader - OSC_ULP Oscillator Watchdog Trap Disable"]
 pub struct ULPWDGT_R(crate::FieldReader<bool, ULPWDGT_A>);
 impl ULPWDGT_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -473,19 +473,19 @@ impl ULPWDGT_R {
     #[inline(always)]
     pub fn variant(&self) -> ULPWDGT_A {
         match self.bits {
-            false => ULPWDGT_A::VALUE1,
-            true => ULPWDGT_A::VALUE2,
+            false => ULPWDGT_A::CONST_0,
+            true => ULPWDGT_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == ULPWDGT_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == ULPWDGT_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == ULPWDGT_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == ULPWDGT_A::CONST_1
     }
 }
 impl core::ops::Deref for ULPWDGT_R {
@@ -495,7 +495,7 @@ impl core::ops::Deref for ULPWDGT_R {
         &self.0
     }
 }
-#[doc = "Field `ULPWDGT` writer - Wake-up Trap Disable"]
+#[doc = "Field `ULPWDGT` writer - OSC_ULP Oscillator Watchdog Trap Disable"]
 pub struct ULPWDGT_W<'a> {
     w: &'a mut W,
 }
@@ -507,13 +507,13 @@ impl<'a> ULPWDGT_W<'a> {
     }
     #[doc = "Trap request enabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(ULPWDGT_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(ULPWDGT_A::CONST_0)
     }
     #[doc = "Trap request disabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(ULPWDGT_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(ULPWDGT_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> ULPWDGT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum BWERR0T_A {
     #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<BWERR0T_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl BWERR0T_R {
     #[inline(always)]
     pub fn variant(&self) -> BWERR0T_A {
         match self.bits {
-            false => BWERR0T_A::VALUE1,
-            true => BWERR0T_A::VALUE2,
+            false => BWERR0T_A::CONST_0,
+            true => BWERR0T_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == BWERR0T_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == BWERR0T_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == BWERR0T_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == BWERR0T_A::CONST_1
     }
 }
 impl core::ops::Deref for BWERR0T_R {
@@ -590,13 +590,13 @@ impl<'a> BWERR0T_W<'a> {
     }
     #[doc = "Trap request enabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(BWERR0T_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(BWERR0T_A::CONST_0)
     }
     #[doc = "Trap request disabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(BWERR0T_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(BWERR0T_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +619,9 @@ impl<'a> BWERR0T_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum BWERR1T_A {
     #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
 impl From<BWERR1T_A> for bool {
     #[inline(always)]
@@ -639,19 +639,19 @@ impl BWERR1T_R {
     #[inline(always)]
     pub fn variant(&self) -> BWERR1T_A {
         match self.bits {
-            false => BWERR1T_A::VALUE1,
-            true => BWERR1T_A::VALUE2,
+            false => BWERR1T_A::CONST_0,
+            true => BWERR1T_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == BWERR1T_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == BWERR1T_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == BWERR1T_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == BWERR1T_A::CONST_1
     }
 }
 impl core::ops::Deref for BWERR1T_R {
@@ -673,13 +673,13 @@ impl<'a> BWERR1T_W<'a> {
     }
     #[doc = "Trap request enabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(BWERR1T_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(BWERR1T_A::CONST_0)
     }
     #[doc = "Trap request disabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(BWERR1T_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(BWERR1T_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -698,71 +698,71 @@ impl<'a> BWERR1T_W<'a> {
         self.w
     }
 }
-#[doc = "Die Temperature Too High Trap Disable\n\nValue on reset: 1"]
+#[doc = "EtherCat Reset 0 Trap Disable\n\nValue on reset: 1"]
 #[derive(Clone, Copy, Debug, PartialEq)]
-pub enum TEMPHIT_A {
+pub enum ECAT0RST_A {
     #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
+    CONST_0 = 0,
     #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
+    CONST_1 = 1,
 }
-impl From<TEMPHIT_A> for bool {
+impl From<ECAT0RST_A> for bool {
     #[inline(always)]
-    fn from(variant: TEMPHIT_A) -> Self {
+    fn from(variant: ECAT0RST_A) -> Self {
         variant as u8 != 0
     }
 }
-#[doc = "Field `TEMPHIT` reader - Die Temperature Too High Trap Disable"]
-pub struct TEMPHIT_R(crate::FieldReader<bool, TEMPHIT_A>);
-impl TEMPHIT_R {
+#[doc = "Field `ECAT0RST` reader - EtherCat Reset 0 Trap Disable"]
+pub struct ECAT0RST_R(crate::FieldReader<bool, ECAT0RST_A>);
+impl ECAT0RST_R {
     pub(crate) fn new(bits: bool) -> Self {
-        TEMPHIT_R(crate::FieldReader::new(bits))
+        ECAT0RST_R(crate::FieldReader::new(bits))
     }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> TEMPHIT_A {
+    pub fn variant(&self) -> ECAT0RST_A {
         match self.bits {
-            false => TEMPHIT_A::VALUE1,
-            true => TEMPHIT_A::VALUE2,
+            false => ECAT0RST_A::CONST_0,
+            true => ECAT0RST_A::CONST_1,
         }
     }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[doc = "Checks if the value of the field is `CONST_0`"]
     #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == TEMPHIT_A::VALUE1
+    pub fn is_const_0(&self) -> bool {
+        **self == ECAT0RST_A::CONST_0
     }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[doc = "Checks if the value of the field is `CONST_1`"]
     #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == TEMPHIT_A::VALUE2
+    pub fn is_const_1(&self) -> bool {
+        **self == ECAT0RST_A::CONST_1
     }
 }
-impl core::ops::Deref for TEMPHIT_R {
-    type Target = crate::FieldReader<bool, TEMPHIT_A>;
+impl core::ops::Deref for ECAT0RST_R {
+    type Target = crate::FieldReader<bool, ECAT0RST_A>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Field `TEMPHIT` writer - Die Temperature Too High Trap Disable"]
-pub struct TEMPHIT_W<'a> {
+#[doc = "Field `ECAT0RST` writer - EtherCat Reset 0 Trap Disable"]
+pub struct ECAT0RST_W<'a> {
     w: &'a mut W,
 }
-impl<'a> TEMPHIT_W<'a> {
+impl<'a> ECAT0RST_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
-    pub fn variant(self, variant: TEMPHIT_A) -> &'a mut W {
+    pub fn variant(self, variant: ECAT0RST_A) -> &'a mut W {
         self.bit(variant.into())
     }
     #[doc = "Trap request enabled"]
     #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(TEMPHIT_A::VALUE1)
+    pub fn const_0(self) -> &'a mut W {
+        self.variant(ECAT0RST_A::CONST_0)
     }
     #[doc = "Trap request disabled"]
     #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(TEMPHIT_A::VALUE2)
+    pub fn const_1(self) -> &'a mut W {
+        self.variant(ECAT0RST_A::CONST_1)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -777,95 +777,12 @@ impl<'a> TEMPHIT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
-        self.w
-    }
-}
-#[doc = "Die Temperature Too Low Trap Disable\n\nValue on reset: 1"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum TEMPLOT_A {
-    #[doc = "0: Trap request enabled"]
-    VALUE1 = 0,
-    #[doc = "1: Trap request disabled"]
-    VALUE2 = 1,
-}
-impl From<TEMPLOT_A> for bool {
-    #[inline(always)]
-    fn from(variant: TEMPLOT_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `TEMPLOT` reader - Die Temperature Too Low Trap Disable"]
-pub struct TEMPLOT_R(crate::FieldReader<bool, TEMPLOT_A>);
-impl TEMPLOT_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        TEMPLOT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> TEMPLOT_A {
-        match self.bits {
-            false => TEMPLOT_A::VALUE1,
-            true => TEMPLOT_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == TEMPLOT_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == TEMPLOT_A::VALUE2
-    }
-}
-impl core::ops::Deref for TEMPLOT_R {
-    type Target = crate::FieldReader<bool, TEMPLOT_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `TEMPLOT` writer - Die Temperature Too Low Trap Disable"]
-pub struct TEMPLOT_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> TEMPLOT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TEMPLOT_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "Trap request enabled"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(TEMPLOT_A::VALUE1)
-    }
-    #[doc = "Trap request disabled"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(TEMPLOT_A::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
 impl R {
-    #[doc = "Bit 0 - System OSC WDT Trap Disable"]
+    #[doc = "Bit 0 - OSC_HP Oscillator Watchdog Trap Disable"]
     #[inline(always)]
     pub fn soscwdgt(&self) -> SOSCWDGT_R {
         SOSCWDGT_R::new((self.bits & 0x01) != 0)
@@ -890,7 +807,7 @@ impl R {
     pub fn brwnt(&self) -> BRWNT_R {
         BRWNT_R::new(((self.bits >> 5) & 0x01) != 0)
     }
-    #[doc = "Bit 6 - Wake-up Trap Disable"]
+    #[doc = "Bit 6 - OSC_ULP Oscillator Watchdog Trap Disable"]
     #[inline(always)]
     pub fn ulpwdgt(&self) -> ULPWDGT_R {
         ULPWDGT_R::new(((self.bits >> 6) & 0x01) != 0)
@@ -905,19 +822,14 @@ impl R {
     pub fn bwerr1t(&self) -> BWERR1T_R {
         BWERR1T_R::new(((self.bits >> 8) & 0x01) != 0)
     }
-    #[doc = "Bit 12 - Die Temperature Too High Trap Disable"]
+    #[doc = "Bit 16 - EtherCat Reset 0 Trap Disable"]
     #[inline(always)]
-    pub fn temphit(&self) -> TEMPHIT_R {
-        TEMPHIT_R::new(((self.bits >> 12) & 0x01) != 0)
-    }
-    #[doc = "Bit 13 - Die Temperature Too Low Trap Disable"]
-    #[inline(always)]
-    pub fn templot(&self) -> TEMPLOT_R {
-        TEMPLOT_R::new(((self.bits >> 13) & 0x01) != 0)
+    pub fn ecat0rst(&self) -> ECAT0RST_R {
+        ECAT0RST_R::new(((self.bits >> 16) & 0x01) != 0)
     }
 }
 impl W {
-    #[doc = "Bit 0 - System OSC WDT Trap Disable"]
+    #[doc = "Bit 0 - OSC_HP Oscillator Watchdog Trap Disable"]
     #[inline(always)]
     pub fn soscwdgt(&mut self) -> SOSCWDGT_W {
         SOSCWDGT_W { w: self }
@@ -942,7 +854,7 @@ impl W {
     pub fn brwnt(&mut self) -> BRWNT_W {
         BRWNT_W { w: self }
     }
-    #[doc = "Bit 6 - Wake-up Trap Disable"]
+    #[doc = "Bit 6 - OSC_ULP Oscillator Watchdog Trap Disable"]
     #[inline(always)]
     pub fn ulpwdgt(&mut self) -> ULPWDGT_W {
         ULPWDGT_W { w: self }
@@ -957,15 +869,10 @@ impl W {
     pub fn bwerr1t(&mut self) -> BWERR1T_W {
         BWERR1T_W { w: self }
     }
-    #[doc = "Bit 12 - Die Temperature Too High Trap Disable"]
+    #[doc = "Bit 16 - EtherCat Reset 0 Trap Disable"]
     #[inline(always)]
-    pub fn temphit(&mut self) -> TEMPHIT_W {
-        TEMPHIT_W { w: self }
-    }
-    #[doc = "Bit 13 - Die Temperature Too Low Trap Disable"]
-    #[inline(always)]
-    pub fn templot(&mut self) -> TEMPLOT_W {
-        TEMPLOT_W { w: self }
+    pub fn ecat0rst(&mut self) -> ECAT0RST_W {
+        ECAT0RST_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
@@ -987,10 +894,10 @@ impl crate::Readable for TRAPDIS_SPEC {
 impl crate::Writable for TRAPDIS_SPEC {
     type Writer = W;
 }
-#[doc = "`reset()` method sets TRAPDIS to value 0x31ff"]
+#[doc = "`reset()` method sets TRAPDIS to value 0x0001_01fd"]
 impl crate::Resettable for TRAPDIS_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0x31ff
+        0x0001_01fd
     }
 }
